import { __decorate, __spread, __param, __read } from 'tslib';
import { Renderer2, ElementRef, Input, HostBinding, Component, ChangeDetectionStrategy, NgModule, EventEmitter, ChangeDetectorRef, Output, forwardRef, Directive, ViewChild, InjectionToken, Inject, Injectable, Optional, ContentChildren, HostListener } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NG_VALUE_ACCESSOR, FormsModule, FormGroupName, NgModelGroup, FormGroupDirective, NgForm } from '@angular/forms';
import { RouterModule } from '@angular/router';
import { Subject } from 'rxjs';

function convertToBoolean(value) {
    if (typeof value === 'string') {
        value = value.toLowerCase().trim();
        return (value === 'true' || value === '');
    }
    return !!value;
}

var VeilButtonComponent = /** @class */ (function () {
    function VeilButtonComponent(renderer, hostElement) {
        this.renderer = renderer;
        this.hostElement = hostElement;
        /**
         * Disables the button
         */
        this._disabled = false;
    }
    Object.defineProperty(VeilButtonComponent.prototype, "info", {
        get: function () {
            return this.status === 'info';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilButtonComponent.prototype, "success", {
        get: function () {
            return this.status === 'success';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilButtonComponent.prototype, "warning", {
        get: function () {
            return this.status === 'warning';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilButtonComponent.prototype, "danger", {
        get: function () {
            return this.status === 'danger';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilButtonComponent.prototype, "outline", {
        get: function () {
            return this.appearance === 'outline';
        },
        set: function (value) {
            if (convertToBoolean(value)) {
                this.appearance = 'outline';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilButtonComponent.prototype, "disabled", {
        get: function () {
            return this._disabled;
        },
        set: function (value) {
            this._disabled = convertToBoolean(value);
            this.renderer.setProperty(this.hostElement.nativeElement, 'disabled', this.disabled);
        },
        enumerable: true,
        configurable: true
    });
    VeilButtonComponent.ctorParameters = function () { return [
        { type: Renderer2 },
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], VeilButtonComponent.prototype, "status", void 0);
    __decorate([
        HostBinding('class.status-info')
    ], VeilButtonComponent.prototype, "info", null);
    __decorate([
        HostBinding('class.status-success')
    ], VeilButtonComponent.prototype, "success", null);
    __decorate([
        HostBinding('class.status-warning')
    ], VeilButtonComponent.prototype, "warning", null);
    __decorate([
        HostBinding('class.status-danger')
    ], VeilButtonComponent.prototype, "danger", null);
    __decorate([
        Input()
    ], VeilButtonComponent.prototype, "appearance", void 0);
    __decorate([
        Input(),
        HostBinding('class.outline')
    ], VeilButtonComponent.prototype, "outline", null);
    __decorate([
        Input(),
        HostBinding('attr.aria-disabled'),
        HostBinding('class.disabled')
    ], VeilButtonComponent.prototype, "disabled", null);
    VeilButtonComponent = __decorate([
        Component({
            // tslint:disable-next-line
            selector: 'button[veilButton], a[veilButton], input[type="button"][veilButton], input[type="submit"][veilButton]',
            template: '<ng-content></ng-content>',
            changeDetection: ChangeDetectionStrategy.OnPush,
            styles: [":host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-family:inherit;cursor:pointer;-webkit-appearance:none!important;border-radius:.25rem;max-width:18rem;white-space:nowrap;text-overflow:ellipsis;overflow:hidden;text-align:center;border:.05rem solid #edf1f7;background-color:#fff;color:#282828;padding:.4rem .5rem;outline:0;margin:2px 2px 2px 0}:host:focus,:host:hover{text-decoration:none}:host:hover{background-color:#e8ebef}:host[disabled]{cursor:not-allowed;background-color:#e0e0e0;color:#a5a5a5}"]
        })
    ], VeilButtonComponent);
    return VeilButtonComponent;
}());

var VeilButtonModule = /** @class */ (function () {
    function VeilButtonModule() {
    }
    VeilButtonModule = __decorate([
        NgModule({
            declarations: [
                VeilButtonComponent
            ],
            imports: [
                CommonModule
            ],
            exports: [
                VeilButtonComponent
            ]
        })
    ], VeilButtonModule);
    return VeilButtonModule;
}());

var VeilCheckboxComponent = /** @class */ (function () {
    function VeilCheckboxComponent(changeDetector) {
        this.changeDetector = changeDetector;
        this._checked = false;
        this._disabled = false;
        this.checkedChange = new EventEmitter();
        this.onChange = function () { };
        this.onTouched = function () { };
    }
    VeilCheckboxComponent_1 = VeilCheckboxComponent;
    Object.defineProperty(VeilCheckboxComponent.prototype, "checked", {
        get: function () {
            return this._checked;
        },
        set: function (value) {
            this._checked = convertToBoolean(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilCheckboxComponent.prototype, "disabled", {
        get: function () {
            return this._disabled;
        },
        set: function (value) {
            this._disabled = convertToBoolean(value);
        },
        enumerable: true,
        configurable: true
    });
    VeilCheckboxComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    VeilCheckboxComponent.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    VeilCheckboxComponent.prototype.writeValue = function (value) {
        this._checked = value;
        this.changeDetector.markForCheck();
    };
    VeilCheckboxComponent.prototype.setDisabledState = function (value) {
        this.disabled = convertToBoolean(value);
        this.changeDetector.markForCheck();
    };
    VeilCheckboxComponent.prototype.setTouched = function () {
        this.onTouched();
    };
    VeilCheckboxComponent.prototype.updateValue = function (event) {
        var input = event.target;
        this.checked = input.checked;
        this.checkedChange.emit(this.checked);
        this.onChange(this.checked);
    };
    var VeilCheckboxComponent_1;
    VeilCheckboxComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    __decorate([
        Input()
    ], VeilCheckboxComponent.prototype, "checked", null);
    __decorate([
        Input()
    ], VeilCheckboxComponent.prototype, "disabled", null);
    __decorate([
        Output()
    ], VeilCheckboxComponent.prototype, "checkedChange", void 0);
    VeilCheckboxComponent = VeilCheckboxComponent_1 = __decorate([
        Component({
            selector: 'veil-checkbox',
            template: "\n    <label class=\"label\">\n      <input type=\"checkbox\" class=\"native-input visually-hidden\"\n        [disabled]=\"disabled\"\n        [checked]=\"checked\"\n        (change)=\"updateValue($event)\"\n        (blur)=\"setTouched()\"\n        (click)=\"$event.stopPropagation()\"\n      >\n      <span [class.checked]=\"checked\" class=\"custom-checkbox\">\n        <i *ngIf=\"checked\" class=\"fa fa-check\" aria-hidden=\"true\"></i>\n      </span>\n      <span class=\"text\">\n        <ng-content></ng-content>\n      </span>\n    </label>\n  ",
            providers: [{
                    provide: NG_VALUE_ACCESSOR,
                    useExisting: forwardRef(function () { return VeilCheckboxComponent_1; }),
                    multi: true
                }],
            changeDetection: ChangeDetectionStrategy.OnPush,
            styles: ["@charset \"UTF-8\";:host{display:-webkit-box;display:-ms-flexbox;display:flex}:host[disabled] .label{cursor:not-allowed}.label{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.custom-checkbox{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;width:1.25rem;height:1.25rem;border-radius:3px;position:relative;background-color:#e8ebef;border:1px solid #a5a5a5}.custom-checkbox.checked{background:#0072a3;color:#fff;border-color:#0072a3}.custom-checkbox i{font-size:1rem}.text{padding-left:.5rem;font-family:inherit;font-weight:600;font-size:.9rem}.native-input:disabled+.custom-checkbox{background-color:#edeff3}.native-input:disabled~.text{color:#9b9b9b}.native-input:disabled+.checked{background-color:#cecece;border-color:#a5a5a5}:host.veil-toggle{padding-left:3px}:host.veil-toggle .label{cursor:pointer}:host.veil-toggle .label .text{font-weight:400;font-size:inherit}:host.veil-toggle .custom-checkbox{width:36px;height:18px;border-radius:50px;background-color:#5a6f88;-webkit-transition:background-color .15s ease-in-out;transition:background-color .15s ease-in-out;border:none}:host.veil-toggle .custom-checkbox:before{content:\"\";width:16px;height:16px;background-color:#fff;border-radius:50%;position:absolute;top:1px;left:1px;-webkit-transition:.15s ease-in-out;transition:.15s ease-in-out;-webkit-box-shadow:inset 0 0 1px 0 rgba(0,0,0,.9);box-shadow:inset 0 0 1px 0 rgba(0,0,0,.9)}:host.veil-toggle .custom-checkbox:after{content:\"\u2715\";color:#fff;font-weight:700;position:absolute;top:3px;left:20px}:host.veil-toggle .custom-checkbox.checked{color:transparent;background-color:#4b9667}:host.veil-toggle .custom-checkbox.checked:before{left:19px}:host.veil-toggle .custom-checkbox.checked:after{content:\"\u2713\";left:5px}:host.veil-toggle[disabled] .label{cursor:default}:host.veil-toggle .native-input:disabled+.custom-checkbox{background-color:rgba(71,71,71,.5)}:host.veil-toggle .native-input:disabled+.custom-checkbox:before{opacity:.5}:host.veil-toggle .native-input:disabled~.text{color:rgba(0,0,0,.7)}"]
        })
    ], VeilCheckboxComponent);
    return VeilCheckboxComponent;
}());

var VeilToggleDirective = /** @class */ (function () {
    function VeilToggleDirective() {
        this.elementClass = 'veil-toggle';
    }
    __decorate([
        HostBinding('class')
    ], VeilToggleDirective.prototype, "elementClass", void 0);
    VeilToggleDirective = __decorate([
        Directive({
            selector: '[veilToggle]',
        })
    ], VeilToggleDirective);
    return VeilToggleDirective;
}());

var VeilCheckboxModule = /** @class */ (function () {
    function VeilCheckboxModule() {
    }
    VeilCheckboxModule = __decorate([
        NgModule({
            declarations: [
                VeilCheckboxComponent,
                VeilToggleDirective
            ],
            imports: [
                CommonModule
            ],
            exports: [
                VeilCheckboxComponent,
                VeilToggleDirective
            ]
        })
    ], VeilCheckboxModule);
    return VeilCheckboxModule;
}());

var VeilInputComponent = /** @class */ (function () {
    function VeilInputComponent() {
    }
    VeilInputComponent = __decorate([
        Component({
            // tslint:disable-next-line
            selector: 'input[veilInput], textarea[veilInput]',
            template: '<ng-content></ng-content>',
            styles: [":host{-webkit-appearance:none;background-color:#f7f9fc;color:#282828;font-size:.9rem;padding:.6rem 1rem;border-radius:.25rem;border:1px solid #e4e9f2;font-family:inherit;font-weight:600}:host::-webkit-input-placeholder{font-weight:400}:host::-moz-placeholder{font-weight:400}:host:-ms-input-placeholder{font-weight:400}:host::-ms-input-placeholder{font-weight:400}:host::placeholder{font-weight:400}:host:focus{outline:0;background-color:#fff;border-color:#0072a3}:host:hover{background-color:#edf1f7;border-color:#e4e9f2}:host:disabled{background-color:#f7f9fc;cursor:not-allowed;color:#c7cedb}:host:disabled::-webkit-input-placeholder{color:#c7cedb}:host:disabled::-moz-placeholder{color:#c7cedb}:host:disabled:-ms-input-placeholder{color:#c7cedb}:host:disabled::-ms-input-placeholder{color:#c7cedb}:host:disabled::placeholder{color:#c7cedb}"]
        })
    ], VeilInputComponent);
    return VeilInputComponent;
}());

var VeilInputModule = /** @class */ (function () {
    function VeilInputModule() {
    }
    VeilInputModule = __decorate([
        NgModule({
            declarations: [
                VeilInputComponent
            ],
            imports: [
                CommonModule
            ],
            exports: [
                VeilInputComponent
            ]
        })
    ], VeilInputModule);
    return VeilInputModule;
}());

/**
 * Layout container component
 */
var VeilLayoutComponent = /** @class */ (function () {
    function VeilLayoutComponent() {
    }
    VeilLayoutComponent = __decorate([
        Component({
            selector: 'veil-layout',
            template: '<ng-content></ng-content>',
            styles: [":host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:inherit;overflow:hidden}:host ::ng-deep veil-layout-title{background-color:#3f606b;display:-webkit-box;display:-ms-flexbox;display:flex;position:relative}:host ::ng-deep veil-layout-title .heading{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:#fff;padding:.4rem .6rem}:host ::ng-deep veil-layout-title .heading i{font-size:1rem;margin-right:.6rem}:host ::ng-deep veil-layout-title .heading h3{font-size:1rem;font-weight:400}:host ::ng-deep veil-layout-title .actions{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin-left:auto}:host ::ng-deep veil-layout-title .actions>:not(:last-child){margin-right:2px}:host ::ng-deep veil-layout-controls{display:-webkit-box;display:-ms-flexbox;display:flex;background-color:#fff;position:relative;border-bottom:1px solid #dedede}:host ::ng-deep veil-layout-controls i{font-size:.8rem}:host ::ng-deep veil-layout-controls>button{background-color:transparent;border:1px solid transparent;border-right:1px solid #ccc;border-radius:0;padding:.8rem 1.2rem;margin:1px}:host ::ng-deep veil-layout-controls>button>span{margin-left:5px;margin-right:5px}:host ::ng-deep veil-layout-controls>button:hover:not(:disabled):not(.status-info):not(.status-success):not(.status-warning):not(.status-danger){background-color:#fafafa;border:1px solid #d4d4d4;border-radius:3px}:host ::ng-deep veil-layout-content{display:-webkit-box;display:-ms-flexbox;display:flex;height:100%;overflow:auto}:host ::ng-deep veil-layout-content>div:not(.left-side){width:100%}:host ::ng-deep veil-layout-content .left-side{position:relative;border-right:1px solid #dedede;height:100%;background-color:#fbfbfb;min-width:140px}:host ::ng-deep veil-layout-content .right-side{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%}:host ::ng-deep veil-layout-footer{border-top:1px solid #dedede;padding:8px 12px;background-color:#fff}"]
        })
    ], VeilLayoutComponent);
    return VeilLayoutComponent;
}());
/**
 * Layout title component
 */
var VeilLayoutTitleComponent = /** @class */ (function () {
    function VeilLayoutTitleComponent() {
        this.heading = '...';
    }
    __decorate([
        Input()
    ], VeilLayoutTitleComponent.prototype, "icon", void 0);
    __decorate([
        Input()
    ], VeilLayoutTitleComponent.prototype, "heading", void 0);
    VeilLayoutTitleComponent = __decorate([
        Component({
            selector: 'veil-layout-title',
            template: "\n    <ng-container>\n      <div class=\"heading\">\n        <i *ngIf=\"icon\" class=\"fa fa-{{ icon }}\" aria-hidden=\"true\"></i>\n        <span>{{ heading }}</span>\n      </div>\n      <div class=\"actions\">\n        <ng-content></ng-content>\n      </div>\n    </ng-container>\n  "
        })
    ], VeilLayoutTitleComponent);
    return VeilLayoutTitleComponent;
}());
/**
 * Layout controls component
 */
var VeilLayoutControlsComponent = /** @class */ (function () {
    function VeilLayoutControlsComponent() {
    }
    VeilLayoutControlsComponent = __decorate([
        Component({
            selector: 'veil-layout-controls',
            template: '<ng-content></ng-content>'
        })
    ], VeilLayoutControlsComponent);
    return VeilLayoutControlsComponent;
}());
/**
 * Layout content component
 */
var VeilLayoutContentComponent = /** @class */ (function () {
    function VeilLayoutContentComponent() {
    }
    VeilLayoutContentComponent = __decorate([
        Component({
            selector: 'veil-layout-content',
            template: '<ng-content></ng-content>'
        })
    ], VeilLayoutContentComponent);
    return VeilLayoutContentComponent;
}());
/**
 * Layout footer component
 */
var VeilLayoutFooterComponent = /** @class */ (function () {
    function VeilLayoutFooterComponent() {
    }
    VeilLayoutFooterComponent = __decorate([
        Component({
            selector: 'veil-layout-footer',
            template: '<ng-content></ng-content>'
        })
    ], VeilLayoutFooterComponent);
    return VeilLayoutFooterComponent;
}());

var VEIL_LAYOUT_COMPONENTS = [
    VeilLayoutComponent,
    VeilLayoutTitleComponent,
    VeilLayoutControlsComponent,
    VeilLayoutContentComponent,
    VeilLayoutFooterComponent
];
var VeilLayoutModule = /** @class */ (function () {
    function VeilLayoutModule() {
    }
    VeilLayoutModule = __decorate([
        NgModule({
            declarations: __spread(VEIL_LAYOUT_COMPONENTS),
            imports: [
                CommonModule
            ],
            exports: __spread(VEIL_LAYOUT_COMPONENTS)
        })
    ], VeilLayoutModule);
    return VeilLayoutModule;
}());

var VeilTableComponent = /** @class */ (function () {
    function VeilTableComponent() {
    }
    __decorate([
        Input()
    ], VeilTableComponent.prototype, "heading", void 0);
    VeilTableComponent = __decorate([
        Component({
            selector: 'veil-table',
            template: "\n    <header *ngIf=\"heading\">{{ heading }}</header>\n    <div class=\"scrollable\">\n      <div class=\"table-wrapper\">\n        <ng-content></ng-content>\n      </div>\n    </div>\n  ",
            styles: [":host{height:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;width:100%}:host header{padding:.4rem .6rem;font-size:1.1rem;text-transform:uppercase;background:#0072a3;color:#fff;margin-bottom:.6rem}:host .scrollable{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;overflow-y:auto;height:100%;background-color:#f5f5f5;background-image:linear-gradient(to right bottom,rgba(255,255,255,0) 8px,#fff 9px,rgba(255,255,255,0) 10px),linear-gradient(to left bottom,rgba(255,255,255,0) 8px,#fff 9px,rgba(255,255,255,0) 10px);background-repeat:repeat;background-size:12px 14px,12px 14px,12px 11px;background-position:0 0,0 0,0 20px}:host .table-wrapper{background-color:#fff;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;width:100%;overflow:hidden}:host ::ng-deep veil-thead{-webkit-box-flex:1;-ms-flex:1 0 auto;flex:1 0 auto;overflow-y:scroll;scrollbar-color:#daebf7 #daebf7}:host ::ng-deep veil-thead::-webkit-scrollbar{background-color:#daebf7}:host ::ng-deep veil-thead ::ng-deep veil-tr{background-color:#daebf7}:host ::ng-deep veil-tr{display:-webkit-box;display:-ms-flexbox;display:flex}:host ::ng-deep veil-td,:host ::ng-deep veil-th{padding:.4rem .8rem;-webkit-box-flex:100;-ms-flex:100 0 auto;flex:100 0 auto;width:100px}:host ::ng-deep veil-tbody{overflow-y:scroll}:host ::ng-deep veil-tbody ::ng-deep veil-tr{border-bottom:1px solid rgba(0,0,0,.15)}:host ::ng-deep veil-tbody ::ng-deep veil-tr:hover{background-color:rgba(0,0,0,.04)}:host ::ng-deep veil-tbody ::ng-deep veil-td:not(:last-child){border-right:1px solid rgba(0,0,0,.15)}"]
        })
    ], VeilTableComponent);
    return VeilTableComponent;
}());
var VeilTheadComponent = /** @class */ (function () {
    function VeilTheadComponent() {
    }
    VeilTheadComponent = __decorate([
        Component({
            selector: 'veil-thead',
            template: '<ng-content></ng-content>'
        })
    ], VeilTheadComponent);
    return VeilTheadComponent;
}());
var VeilTbodyComponent = /** @class */ (function () {
    function VeilTbodyComponent() {
    }
    VeilTbodyComponent = __decorate([
        Component({
            selector: 'veil-tbody',
            template: '<ng-content></ng-content>'
        })
    ], VeilTbodyComponent);
    return VeilTbodyComponent;
}());
var VeilTrComponent = /** @class */ (function () {
    function VeilTrComponent() {
    }
    VeilTrComponent = __decorate([
        Component({
            selector: 'veil-tr',
            template: '<ng-content></ng-content>'
        })
    ], VeilTrComponent);
    return VeilTrComponent;
}());
var VeilTdComponent = /** @class */ (function () {
    function VeilTdComponent() {
    }
    VeilTdComponent = __decorate([
        Component({
            selector: 'veil-td',
            template: '<ng-content></ng-content>'
        })
    ], VeilTdComponent);
    return VeilTdComponent;
}());
var VeilThComponent = /** @class */ (function () {
    function VeilThComponent() {
    }
    VeilThComponent = __decorate([
        Component({
            selector: 'veil-th',
            template: '<ng-content></ng-content>'
        })
    ], VeilThComponent);
    return VeilThComponent;
}());

var VeilTableModule = /** @class */ (function () {
    function VeilTableModule() {
    }
    VeilTableModule = __decorate([
        NgModule({
            declarations: [
                VeilTableComponent,
                VeilTheadComponent,
                VeilTbodyComponent,
                VeilTrComponent,
                VeilTdComponent,
                VeilThComponent
            ],
            imports: [
                CommonModule,
            ],
            exports: [
                VeilTableComponent,
                VeilTheadComponent,
                VeilTbodyComponent,
                VeilTrComponent,
                VeilTdComponent,
                VeilThComponent
            ]
        })
    ], VeilTableModule);
    return VeilTableModule;
}());

var VeilSelectComponent = /** @class */ (function () {
    function VeilSelectComponent() {
    }
    VeilSelectComponent = __decorate([
        Component({
            // tslint:disable-next-line
            selector: 'select[veilSelect]',
            template: '<ng-content></ng-content>',
            changeDetection: ChangeDetectionStrategy.OnPush,
            styles: [":host{background-color:#f7f9fc;color:#282828;font-size:.9rem;font-weight:600;padding:calc(.6rem - 1px) 2rem calc(.6rem - 1px) 1rem;border-radius:.25rem;border:1px solid #e4e9f2;font-family:inherit}:host:focus{outline:0;background-color:#fff;border-color:#0072a3}:host:hover{background-color:#edf1f7;border-color:#e4e9f2}:host:disabled{background-color:#f7f9fc;cursor:not-allowed;color:#c7cedb}"]
        })
    ], VeilSelectComponent);
    return VeilSelectComponent;
}());

var VeilSelectModule = /** @class */ (function () {
    function VeilSelectModule() {
    }
    VeilSelectModule = __decorate([
        NgModule({
            declarations: [
                VeilSelectComponent
            ],
            imports: [
                CommonModule
            ],
            exports: [
                VeilSelectComponent
            ]
        })
    ], VeilSelectModule);
    return VeilSelectModule;
}());

var VeilSidenavComponent = /** @class */ (function () {
    function VeilSidenavComponent() {
    }
    VeilSidenavComponent = __decorate([
        Component({
            selector: 'veil-sidenav',
            template: "\n    <nav>\n      <ng-content></ng-content>\n    </nav>\n  ",
            styles: ["nav{padding:.6rem}"]
        })
    ], VeilSidenavComponent);
    return VeilSidenavComponent;
}());

var VeilSidenavModule = /** @class */ (function () {
    function VeilSidenavModule() {
    }
    VeilSidenavModule = __decorate([
        NgModule({
            declarations: [
                VeilSidenavComponent
            ],
            imports: [
                CommonModule,
                RouterModule
            ],
            exports: [
                VeilSidenavComponent
            ]
        })
    ], VeilSidenavModule);
    return VeilSidenavModule;
}());

var VeilSpinnerComponent = /** @class */ (function () {
    function VeilSpinnerComponent() {
    }
    VeilSpinnerComponent = __decorate([
        Component({
            selector: 'veil-spinner',
            template: 'Loading...',
            styles: [":host{position:relative;display:inline-block;height:3.5rem;width:3.5rem;min-height:3.5rem;min-width:3.5rem;-webkit-animation:1s linear infinite spin;animation:1s linear infinite spin;margin:0;padding:0;background:url(data:image/svg+xml;charset=utf8,%3Csvg%20id%3D%22Layer_2%22%20data-name%3D%22Layer%202%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20viewBox%3D%220%200%2072%2072%22%3E%0A%20%20%20%20%3Cdefs%3E%0A%20%20%20%20%20%20%20%20%3Cstyle%3E%0A%20%20%20%20%20%20%20%20%20%20%20%20.cls-1%2C%0A%20%20%20%20%20%20%20%20%20%20%20%20.cls-2%20%7B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20fill%3A%20none%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20stroke-miterlimit%3A%2010%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20stroke-width%3A%205px%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%7D%0A%20%20%20%20%20%20%20%20%20%20%20%20.cls-1%20%7B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20stroke%3A%20%23000000%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20stroke-opacity%3A%200.15%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%7D%0A%20%20%20%20%20%20%20%20%20%20%20%20.cls-2%20%7B%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20stroke%3A%20%230072a3%3B%0A%20%20%20%20%20%20%20%20%20%20%20%20%7D%0A%20%20%20%20%20%20%20%20%3C%2Fstyle%3E%0A%20%20%20%20%3C%2Fdefs%3E%0A%20%20%20%20%3Ctitle%3EPreloader_72x2%3C%2Ftitle%3E%0A%20%20%20%20%3Ccircle%20class%3D%22cls-1%22%20cx%3D%2236%22%20cy%3D%2236%22%20r%3D%2233%22%2F%3E%0A%20%20%20%20%3Cpath%20class%3D%22cls-2%22%20d%3D%22M14.3%2C60.9A33%2C33%2C0%2C0%2C1%2C36%2C3%22%3E%0A%20%20%20%20%3C%2Fpath%3E%0A%3C%2Fsvg%3E%0A);text-indent:100%;overflow:hidden;white-space:nowrap}:host.md{height:1.7rem;width:1.7rem;min-height:1.7rem;min-width:1.7rem}:host.inline,:host.sm{height:1rem;width:1rem;min-height:1rem;min-width:1rem}:host.inline{vertical-align:text-bottom}@-webkit-keyframes spin{0%{-webkit-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes spin{0%{-webkit-transform:rotate(0);transform:rotate(0)}100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}"]
        })
    ], VeilSpinnerComponent);
    return VeilSpinnerComponent;
}());

var VeilSpinnerModule = /** @class */ (function () {
    function VeilSpinnerModule() {
    }
    VeilSpinnerModule = __decorate([
        NgModule({
            exports: [
                VeilSpinnerComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilSpinnerComponent
            ],
        })
    ], VeilSpinnerModule);
    return VeilSpinnerModule;
}());

var VeilListComponent = /** @class */ (function () {
    function VeilListComponent() {
    }
    VeilListComponent = __decorate([
        Component({
            selector: 'veil-list',
            template: '<ng-content></ng-content>',
            styles: [":host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap}:host ::ng-deep veil-list{padding:.8rem 0 0 .8rem}:host ::ng-deep veil-list ::ng-deep veil-list-title+::ng-deep veil-line{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-list-title{padding-top:0}:host ::ng-deep veil-list ::ng-deep veil-line{border-left:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-line:first-child{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:nowrap;flex-wrap:nowrap;border-bottom:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-line ::ng-deep veil-line-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line ::ng-deep veil-line-item{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding:.4rem .8rem}:host ::ng-deep veil-line ::ng-deep veil-line-item:first-child{color:rgba(0,0,0,.6);font-weight:400}:host ::ng-deep veil-line ::ng-deep veil-line-item:last-child{color:#4b5e61;font-weight:700}"]
        })
    ], VeilListComponent);
    return VeilListComponent;
}());
var VeilListTitleComponent = /** @class */ (function () {
    function VeilListTitleComponent() {
    }
    VeilListTitleComponent = __decorate([
        Component({
            selector: 'veil-list-title',
            template: '<ng-content></ng-content>',
            styles: [":host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap}:host ::ng-deep veil-list{padding:.8rem 0 0 .8rem}:host ::ng-deep veil-list ::ng-deep veil-list-title+::ng-deep veil-line{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-list-title{padding-top:0}:host ::ng-deep veil-list ::ng-deep veil-line{border-left:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-line:first-child{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:nowrap;flex-wrap:nowrap;border-bottom:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-line ::ng-deep veil-line-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line ::ng-deep veil-line-item{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding:.4rem .8rem}:host ::ng-deep veil-line ::ng-deep veil-line-item:first-child{color:rgba(0,0,0,.6);font-weight:400}:host ::ng-deep veil-line ::ng-deep veil-line-item:last-child{color:#4b5e61;font-weight:700}"]
        })
    ], VeilListTitleComponent);
    return VeilListTitleComponent;
}());
var VeilLineComponent = /** @class */ (function () {
    function VeilLineComponent() {
    }
    VeilLineComponent = __decorate([
        Component({
            selector: 'veil-line',
            template: '<ng-content></ng-content>',
            styles: [":host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap}:host ::ng-deep veil-list{padding:.8rem 0 0 .8rem}:host ::ng-deep veil-list ::ng-deep veil-list-title+::ng-deep veil-line{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-list-title{padding-top:0}:host ::ng-deep veil-list ::ng-deep veil-line{border-left:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-line:first-child{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:nowrap;flex-wrap:nowrap;border-bottom:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-line ::ng-deep veil-line-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line ::ng-deep veil-line-item{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding:.4rem .8rem}:host ::ng-deep veil-line ::ng-deep veil-line-item:first-child{color:rgba(0,0,0,.6);font-weight:400}:host ::ng-deep veil-line ::ng-deep veil-line-item:last-child{color:#4b5e61;font-weight:700}"]
        })
    ], VeilLineComponent);
    return VeilLineComponent;
}());
var VeilLineTitleComponent = /** @class */ (function () {
    function VeilLineTitleComponent() {
    }
    VeilLineTitleComponent = __decorate([
        Component({
            selector: 'veil-line-title',
            template: '<ng-content></ng-content>',
            styles: [":host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap}:host ::ng-deep veil-list{padding:.8rem 0 0 .8rem}:host ::ng-deep veil-list ::ng-deep veil-list-title+::ng-deep veil-line{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-list-title{padding-top:0}:host ::ng-deep veil-list ::ng-deep veil-line{border-left:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-line:first-child{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:nowrap;flex-wrap:nowrap;border-bottom:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-line ::ng-deep veil-line-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line ::ng-deep veil-line-item{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding:.4rem .8rem}:host ::ng-deep veil-line ::ng-deep veil-line-item:first-child{color:rgba(0,0,0,.6);font-weight:400}:host ::ng-deep veil-line ::ng-deep veil-line-item:last-child{color:#4b5e61;font-weight:700}"]
        })
    ], VeilLineTitleComponent);
    return VeilLineTitleComponent;
}());
var VeilLineItemComponent = /** @class */ (function () {
    function VeilLineItemComponent() {
    }
    Object.defineProperty(VeilLineItemComponent.prototype, "width", {
        get: function () {
            return this.vlSize + '%';
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        Input()
    ], VeilLineItemComponent.prototype, "vlSize", void 0);
    __decorate([
        HostBinding('style.width')
    ], VeilLineItemComponent.prototype, "width", null);
    VeilLineItemComponent = __decorate([
        Component({
            selector: 'veil-line-item',
            template: '<ng-content></ng-content>',
            styles: [":host{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-ms-flex-wrap:nowrap;flex-wrap:nowrap}:host ::ng-deep veil-list{padding:.8rem 0 0 .8rem}:host ::ng-deep veil-list ::ng-deep veil-list-title+::ng-deep veil-line{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-list-title{padding-top:0}:host ::ng-deep veil-list ::ng-deep veil-line{border-left:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list ::ng-deep veil-line:first-child{border-top:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-list-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:nowrap;flex-wrap:nowrap;border-bottom:1px solid rgba(0,0,0,.1)}:host ::ng-deep veil-line ::ng-deep veil-line-title{font-weight:700;padding:.4rem .8rem;color:#4b5e61}:host ::ng-deep veil-line ::ng-deep veil-line-item{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding:.4rem .8rem}:host ::ng-deep veil-line ::ng-deep veil-line-item:first-child{color:rgba(0,0,0,.6);font-weight:400}:host ::ng-deep veil-line ::ng-deep veil-line-item:last-child{color:#4b5e61;font-weight:700}"]
        })
    ], VeilLineItemComponent);
    return VeilLineItemComponent;
}());

var VEIL_LIST_COMPONENTS = [
    VeilListComponent,
    VeilListTitleComponent,
    VeilLineComponent,
    VeilLineTitleComponent,
    VeilLineItemComponent
];
var VeilListModule = /** @class */ (function () {
    function VeilListModule() {
    }
    VeilListModule = __decorate([
        NgModule({
            exports: __spread(VEIL_LIST_COMPONENTS),
            imports: [
                CommonModule
            ],
            declarations: __spread(VEIL_LIST_COMPONENTS),
        })
    ], VeilListModule);
    return VeilListModule;
}());

var VeilDropdownComponent = /** @class */ (function () {
    function VeilDropdownComponent(renderer) {
        var _this = this;
        this.renderer = renderer;
        this.isOpen = false;
        this.renderer.listen('document', 'click', function (e) {
            var element = e.target;
            if (!_this.toggleButton.nativeElement.contains(e.target) && !_this.menu.nativeElement.contains(e.target)
                || _this.menu.nativeElement.contains(e.target) && element.className.includes('rollup')) {
                _this.isOpen = false;
            }
        });
    }
    VeilDropdownComponent.prototype.menuToggle = function () {
        this.isOpen = !this.isOpen;
    };
    VeilDropdownComponent.ctorParameters = function () { return [
        { type: Renderer2 }
    ]; };
    __decorate([
        ViewChild('toggleButton')
    ], VeilDropdownComponent.prototype, "toggleButton", void 0);
    __decorate([
        ViewChild('menu')
    ], VeilDropdownComponent.prototype, "menu", void 0);
    VeilDropdownComponent = __decorate([
        Component({
            selector: 'veil-dropdown',
            template: "\n    <ng-container>\n      <div (click)=\"menuToggle()\" #toggleButton>\n        <ng-content select=\"veil-dropdown-toggle\"></ng-content>\n      </div>\n      <div #menu>\n        <ng-content *ngIf=\"isOpen\" select=\"veil-dropdown-menu\"></ng-content>\n      </div>\n    </ng-container>\n  ",
            styles: [":host{display:inline-block;position:relative}:host>div{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}:host ::ng-deep veil-dropdown-toggle{display:inline-block}:host ::ng-deep veil-dropdown-menu{display:block;position:absolute;top:0;left:0;-webkit-transform:translate(0,34px);transform:translate(0,34px);background-color:#fff;border:1px solid rgba(0,0,0,.15);border-radius:.25rem;padding:.4rem 0;min-width:5rem;-webkit-box-shadow:0 3px 6px -2px rgba(0,0,0,.2);box-shadow:0 3px 6px -2px rgba(0,0,0,.2);z-index:1000}:host ::ng-deep veil-dropdown-menu button,:host ::ng-deep veil-dropdown-menu>a{text-decoration:none;background-color:transparent;width:100%;border:none;border-radius:0}:host ::ng-deep veil-dropdown-menu[placement=right]{right:0;left:auto}"]
        })
    ], VeilDropdownComponent);
    return VeilDropdownComponent;
}());
var VeilDropdownControlComponent = /** @class */ (function () {
    function VeilDropdownControlComponent() {
    }
    VeilDropdownControlComponent = __decorate([
        Component({
            selector: 'veil-dropdown-toggle',
            template: '<ng-content></ng-content>',
            styles: [":host{display:inline-block;position:relative}:host>div{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}:host ::ng-deep veil-dropdown-toggle{display:inline-block}:host ::ng-deep veil-dropdown-menu{display:block;position:absolute;top:0;left:0;-webkit-transform:translate(0,34px);transform:translate(0,34px);background-color:#fff;border:1px solid rgba(0,0,0,.15);border-radius:.25rem;padding:.4rem 0;min-width:5rem;-webkit-box-shadow:0 3px 6px -2px rgba(0,0,0,.2);box-shadow:0 3px 6px -2px rgba(0,0,0,.2);z-index:1000}:host ::ng-deep veil-dropdown-menu button,:host ::ng-deep veil-dropdown-menu>a{text-decoration:none;background-color:transparent;width:100%;border:none;border-radius:0}:host ::ng-deep veil-dropdown-menu[placement=right]{right:0;left:auto}"]
        })
    ], VeilDropdownControlComponent);
    return VeilDropdownControlComponent;
}());
var VeilDropdownMenuComponent = /** @class */ (function () {
    function VeilDropdownMenuComponent() {
    }
    Object.defineProperty(VeilDropdownMenuComponent.prototype, "value", {
        get: function () {
            return this.placement;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        Input()
    ], VeilDropdownMenuComponent.prototype, "placement", void 0);
    __decorate([
        HostBinding('attr.placement')
    ], VeilDropdownMenuComponent.prototype, "value", null);
    VeilDropdownMenuComponent = __decorate([
        Component({
            selector: 'veil-dropdown-menu',
            template: '<ng-content></ng-content>',
            styles: [":host{display:inline-block;position:relative}:host>div{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}:host ::ng-deep veil-dropdown-toggle{display:inline-block}:host ::ng-deep veil-dropdown-menu{display:block;position:absolute;top:0;left:0;-webkit-transform:translate(0,34px);transform:translate(0,34px);background-color:#fff;border:1px solid rgba(0,0,0,.15);border-radius:.25rem;padding:.4rem 0;min-width:5rem;-webkit-box-shadow:0 3px 6px -2px rgba(0,0,0,.2);box-shadow:0 3px 6px -2px rgba(0,0,0,.2);z-index:1000}:host ::ng-deep veil-dropdown-menu button,:host ::ng-deep veil-dropdown-menu>a{text-decoration:none;background-color:transparent;width:100%;border:none;border-radius:0}:host ::ng-deep veil-dropdown-menu[placement=right]{right:0;left:auto}"]
        })
    ], VeilDropdownMenuComponent);
    return VeilDropdownMenuComponent;
}());

var VeilDropdownModule = /** @class */ (function () {
    function VeilDropdownModule() {
    }
    VeilDropdownModule = __decorate([
        NgModule({
            exports: [
                VeilDropdownComponent,
                VeilDropdownControlComponent,
                VeilDropdownMenuComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilDropdownComponent,
                VeilDropdownControlComponent,
                VeilDropdownMenuComponent
            ],
        })
    ], VeilDropdownModule);
    return VeilDropdownModule;
}());

var instances = 0;
var uniqueId = new InjectionToken('uniqueId');
function uniqueIdFactory() {
    return 'id-' + instances++;
}
var UNIQUE_ID_PROVIDER = {
    provide: uniqueId,
    useFactory: uniqueIdFactory,
};

var VeilTreeComponent = /** @class */ (function () {
    function VeilTreeComponent(nodeId) {
        this.nodeId = nodeId;
        this.output = new EventEmitter();
        this.flatNodes = new EventEmitter();
    }
    VeilTreeComponent.prototype.ngOnInit = function () {
        this.emitFilteredNodes();
    };
    VeilTreeComponent.prototype.emitFilteredNodes = function () {
        if (!this.parent) {
            var filteredNodes = [];
            this.recursiveFilter(this.nodes, filteredNodes);
            this.flatNodes.emit(filteredNodes);
        }
    };
    VeilTreeComponent.prototype.recursiveFilter = function (nodes, filteredNodes) {
        var _this = this;
        nodes.forEach(function (node) {
            if (!node.children) {
                filteredNodes.push(node);
            }
            else {
                _this.recursiveFilter(node.children, filteredNodes);
            }
        });
    };
    VeilTreeComponent.prototype.toggleChange = function (evt, node) {
        node.checked = evt.currentTarget.checked;
        if (node.children) {
            var children = node.children, checked = node.checked;
            this.recursiveCheckboxValidation(children, checked);
        }
        this.emitFilteredNodes();
        this.output.emit();
    };
    VeilTreeComponent.prototype.recursiveCheckboxValidation = function (children, checked) {
        var _this = this;
        children.forEach(function (child) {
            child.checked = checked;
            if (child.children) {
                _this.recursiveCheckboxValidation(child.children, checked);
            }
        });
    };
    VeilTreeComponent.prototype.emited = function () {
        this.nodes.forEach(function (node) {
            if (node.children && node.children.every(function (child) { return child.checked; })) {
                node.checked = true;
            }
            if (node.children && node.children.some(function (child) { return !child.checked; })) {
                node.checked = false;
            }
        });
        this.emitFilteredNodes();
        this.output.emit();
    };
    VeilTreeComponent.ctorParameters = function () { return [
        { type: String, decorators: [{ type: Inject, args: [uniqueId,] }] }
    ]; };
    __decorate([
        Input('nodes')
    ], VeilTreeComponent.prototype, "nodes", void 0);
    __decorate([
        Input('parent')
    ], VeilTreeComponent.prototype, "parent", void 0);
    __decorate([
        Output()
    ], VeilTreeComponent.prototype, "output", void 0);
    __decorate([
        Output()
    ], VeilTreeComponent.prototype, "flatNodes", void 0);
    VeilTreeComponent = __decorate([
        Component({
            selector: 'veil-tree',
            template: "<ng-container *ngFor=\"let node of nodes; index as i\">\n  <div class=\"container\">\n    <button\n      [ngStyle]=\"{'visibility': node.children ? 'initial' : 'hidden'}\"\n      class=\"toggle-btn\"\n      type=\"button\"\n      (click)=\"node.toggle = !node.toggle\"\n    >\n      <i\n        class=\"fa fa-chevron-right\"\n        [ngClass]=\"{expanded: node.toggle}\"\n        aria-hidden=\"true\"\n      ></i>\n    </button>\n    <div class=\"checkbox-wrapper\">\n      <input\n        type=\"checkbox\"\n        id=\"check-{{i}}-{{nodeId}}\"\n        [checked]=\"node.checked\"\n        (change)=\"toggleChange($event, node)\"\n      >\n      <label for=\"check-{{i}}-{{nodeId}}\"></label>\n    </div>\n    <div class=\"content\">\n      {{ node.label }}\n    </div>\n  </div>\n  <div\n    *ngIf=\"node.children\"\n    class=\"veil-tree-node-children\"\n    [ngStyle]=\"{'display': node.toggle ? 'block' : 'none' }\"\n  >\n    <veil-tree [nodes]=\"node.children\" [parent]=\"node\" (output)=\"emited()\"></veil-tree>\n  </div>\n</ng-container>",
            providers: [UNIQUE_ID_PROVIDER],
            styles: ["@charset \"UTF-8\";:host{display:block}.container{display:-webkit-box;display:-ms-flexbox;display:flex;padding:.3rem}.toggle-btn{color:rgba(0,0,0,.4);-webkit-appearance:none;border:0;cursor:pointer;background:0 0;outline:0;padding:0 .5rem}.toggle-btn .expanded{-webkit-transform:rotate(90deg);transform:rotate(90deg)}.checkbox-wrapper{position:relative;height:calc(.7rem + 1px);width:calc(.7rem + 1px)}.checkbox-wrapper input[type=checkbox]{position:absolute;opacity:0}.checkbox-wrapper input[type=checkbox]:checked+label:before{content:\"\u2714\"}.checkbox-wrapper label{position:relative;cursor:pointer}.checkbox-wrapper label:hover:before{color:#448c8a;border-color:#448c8a}.checkbox-wrapper label:before{font-size:110%;position:absolute;top:0;left:0;content:\"\";-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-ms-flexbox;display:flex;height:.7rem;width:.7rem;border-radius:.1rem;border:.05rem solid #b3b3b3}.content{padding-left:.4rem}.veil-tree-node-children{margin-left:.8rem}"]
        }),
        __param(0, Inject(uniqueId))
    ], VeilTreeComponent);
    return VeilTreeComponent;
}());

var VeilTreeModule = /** @class */ (function () {
    function VeilTreeModule() {
    }
    VeilTreeModule = __decorate([
        NgModule({
            exports: [
                VeilTreeComponent,
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilTreeComponent,
            ],
        })
    ], VeilTreeModule);
    return VeilTreeModule;
}());

var weekNarrow = ['ПН', 'ВТ', 'СР', 'ЧТ', 'ПТ', 'СБ', 'ВС'];
var months = [
    'Январь', 'Февраль', 'Март',
    'Апрель', 'Май', 'Июнь',
    'Июль', 'Август', 'Сентябрь',
    'Октябрь', 'Ноябрь', 'Декабрь'
];
var DATE_REGEX = /^(0?[1-9]|[12][0-9]|3[01])[\/\-](0?[1-9]|1[012])[\/\-]\d{4}$/;

function format(num) {
    var str = String(num);
    return str.length < 2 ? 0 + str : str;
}
function getNumberOfDaysInTheMonth(year, month) {
    return new Date(year, month + 1, 0).getDate();
}
function datesAreEqual(day, month, year, date) {
    return (day === date.getDate() &&
        month === date.getMonth() &&
        year === date.getFullYear());
}
function dateIsValid(date) {
    return DATE_REGEX.test(date);
}

var VeilDatepickerComponent = /** @class */ (function () {
    function VeilDatepickerComponent(renderer) {
        var _this = this;
        this.renderer = renderer;
        this.date = new Date();
        this.calendarIsOpen = false;
        this.update = new EventEmitter();
        this.renderer.listen('document', 'click', function (evt) {
            if (!_this.inputGroup.nativeElement.contains(evt.target) &&
                !_this.calendar.nativeElement.contains(evt.target)) {
                _this.hideCalendar();
            }
        });
        this.weekNarrow = weekNarrow;
        this.months = months;
    }
    VeilDatepickerComponent.prototype.ngOnInit = function () {
        this.month = this.date.getMonth();
        this.year = this.date.getFullYear();
        this.initCalendarView();
    };
    VeilDatepickerComponent.prototype.inputChange = function (evt) {
        this.selectedDate = new Date();
        if (dateIsValid(this.inputDate)) {
            this.update.emit(this.inputDate);
        }
    };
    VeilDatepickerComponent.prototype.hideCalendar = function () {
        this.calendarIsOpen = false;
    };
    VeilDatepickerComponent.prototype.toggleCalendar = function () {
        this.calendarIsOpen = !this.calendarIsOpen;
        this.month = this.date.getMonth();
        this.year = this.date.getFullYear();
        if (this.calendarIsOpen && dateIsValid(this.inputDate)) {
            this.selectedDate = new Date(this.inputDate.replace(/-/g, '/').split('/').reverse().join('-'));
            this.year = this.selectedDate.getFullYear();
            this.month = this.selectedDate.getMonth();
        }
        this.initCalendarView();
    };
    VeilDatepickerComponent.prototype.updateMonth = function (route) {
        switch (route) {
            case 'prev':
                this.month--;
                break;
            case 'next':
                this.month++;
                break;
            default:
                this.month = this.date.getMonth();
                this.year = this.date.getFullYear();
        }
        if (this.month < 0) {
            this.month = 11;
            this.year--;
        }
        if (this.month > 11) {
            this.month = 0;
            this.year++;
        }
        this.initCalendarView();
    };
    VeilDatepickerComponent.prototype.selectDay = function (day) {
        this.inputDate = format(day.num) + "/" + format(day.month + 1) + "/" + this.year;
        this.hideCalendar();
        this.update.emit(this.inputDate);
    };
    VeilDatepickerComponent.prototype.getMonthData = function (month) {
        var _this = this;
        var days = getNumberOfDaysInTheMonth(this.year, month);
        return new Array(days).fill({}).map(function (day, index) {
            var status = _this.getStatus(index + 1, month);
            return {
                num: index + 1,
                month: month,
                status: status
            };
        });
    };
    VeilDatepickerComponent.prototype.getStatus = function (day, month) {
        if (month !== this.month) {
            return 'excluded';
        }
        if (this.isToday(day) && this.isSelected(day)) {
            return 'today selected';
        }
        if (this.isToday(day)) {
            return 'today';
        }
        if (this.isSelected(day)) {
            return 'selected';
        }
        return '';
    };
    VeilDatepickerComponent.prototype.isToday = function (day) {
        if (datesAreEqual(day, this.month, this.year, this.date)) {
            return true;
        }
        return false;
    };
    VeilDatepickerComponent.prototype.isSelected = function (day) {
        if (dateIsValid(this.inputDate) &&
            datesAreEqual(day, this.month, this.year, this.selectedDate)) {
            return true;
        }
        return false;
    };
    VeilDatepickerComponent.prototype.initCalendarView = function () {
        var previousMonthEndDate = new Date(this.year, this.month, 0);
        var dayOfWeek = previousMonthEndDate.getDay();
        if (dayOfWeek === 0) {
            dayOfWeek = 7;
        }
        var days = __spread(this.getMonthData(this.month - 1).slice(-dayOfWeek), this.getMonthData(this.month), this.getMonthData(this.month + 1)).slice(0, 42);
        // Here we split the array into an array of arrays on 7 days for convenient display on UI
        this.calendarView = days.reduce(function (res, day) {
            if (res[res.length - 1].length === 7) {
                res.push([]);
            }
            res[res.length - 1].push(day);
            return res;
        }, [[]]);
    };
    VeilDatepickerComponent.ctorParameters = function () { return [
        { type: Renderer2 }
    ]; };
    __decorate([
        ViewChild('inputGroup')
    ], VeilDatepickerComponent.prototype, "inputGroup", void 0);
    __decorate([
        ViewChild('calendar')
    ], VeilDatepickerComponent.prototype, "calendar", void 0);
    __decorate([
        Output()
    ], VeilDatepickerComponent.prototype, "update", void 0);
    VeilDatepickerComponent = __decorate([
        Component({
            selector: 'veil-datepicker',
            template: "<div class=\"input-group\" #inputGroup>\n  <input\n    type=\"text\"\n    [(ngModel)]=\"inputDate\"\n    (ngModelChange)=\"inputChange($event)\"\n    (click)=\"hideCalendar()\"\n    (focus)=\"hideCalendar()\"\n  >\n  <button type=\"button\" (click)=\"toggleCalendar()\">\n    <i class=\"fa fa-calendar\" aria-hidden=\"true\"></i>\n  </button>\n</div>\n<div #calendar>\n  <div *ngIf=\"calendarIsOpen\" class=\"calendar\">\n    <div class=\"table-header\">\n      <span>{{ months[month] }} {{ year }}</span>\n      <div class=\"controls\">\n        <button type=\"button\" (click)=\"updateMonth('prev')\">\n          <i class=\"fa fa-angle-left\" aria-hidden=\"true\"></i>\n        </button>\n        <button type=\"button\" (click)=\"updateMonth()\">\n          <i class=\"fa fa-calendar-check-o\" aria-hidden=\"true\"></i>\n        </button>\n        <button type=\"button\" (click)=\"updateMonth('next')\">\n          <i class=\"fa fa-angle-right\" aria-hidden=\"true\"></i>\n        </button>\n      </div>\n    </div>\n    <table>\n      <tr>\n        <th *ngFor=\"let day of weekNarrow\" class=\"calendar-cell\">{{ day }}</th>\n      </tr>\n      <tr *ngFor=\"let row of calendarView\">\n        <td *ngFor=\"let day of row\">\n          <button\n            type=\"button\"\n            class=\"day-btn\"\n            ngClass=\"{{ day.status }}\"\n            (click)=\"selectDay(day)\"\n          >\n            {{ day.num }}\n          </button>\n        </td>\n      </tr>\n    </table>\n  </div>\n</div>\n",
            styles: [":host{position:relative;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}button{outline:0}.input-group{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-width:14rem}.input-group input{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex:1;-ms-flex:1;flex:1;height:30px;background-color:#f9f9f9;padding-left:12px;padding-right:30px;border:1px solid #e8e8e8;border-radius:2px}.input-group button{border:none;font-size:1rem;background:0 0;position:absolute;right:8px;cursor:pointer;color:#1672a3}.calendar{position:absolute;top:auto;right:0;background-color:#fff;padding:.6rem;margin-top:4px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;border:1px solid #ccc;border-radius:2px;-webkit-box-shadow:0 .05rem .15rem rgba(140,140,140,.25);box-shadow:0 .05rem .15rem rgba(140,140,140,.25);z-index:9999}.table-header{font-size:.9rem;padding:.3rem;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:#1672a3}.table-header .controls button{border:0;background:0 0;padding:.3rem;border-radius:.15rem;cursor:pointer;color:inherit}.table-header .controls button:hover{background-color:#e8e8e8}table{border-spacing:0}.calendar-cell{height:1.8rem;width:1.8rem;min-height:1.8rem;min-width:1.8rem;padding:0;text-align:center;color:#666}.day-btn{height:1.8rem;min-width:1.8rem;padding:0;margin:0;border:none;border-radius:.15rem;background:0 0;cursor:pointer;width:100%;color:inherit}.day-btn:hover{background:#e8e8e8}.day-btn.excluded{opacity:.4}.day-btn.excluded:hover{background:0 0}.day-btn.today{font-weight:600;color:#000}.day-btn.selected{background:#d8e3e9;color:#000}"]
        })
    ], VeilDatepickerComponent);
    return VeilDatepickerComponent;
}());

var VeilDatepickerModule = /** @class */ (function () {
    function VeilDatepickerModule() {
    }
    VeilDatepickerModule = __decorate([
        NgModule({
            exports: [
                VeilDatepickerComponent
            ],
            imports: [
                CommonModule,
                FormsModule
            ],
            declarations: [
                VeilDatepickerComponent
            ],
        })
    ], VeilDatepickerModule);
    return VeilDatepickerModule;
}());

var VeilMultiselectComponent = /** @class */ (function () {
    function VeilMultiselectComponent(renderer) {
        var _this = this;
        this.renderer = renderer;
        this._data = [];
        this._limit = 2;
        this._listHeight = 'auto';
        this.isOpen = false;
        this.selectedItems = [];
        this.selected = new EventEmitter();
        this.renderer.listen('document', 'click', function (evt) {
            if (_this.list &&
                !_this.inputGroup.nativeElement.contains(evt.target) &&
                !_this.list.nativeElement.contains(evt.target)) {
                _this.isOpen = false;
            }
        });
    }
    Object.defineProperty(VeilMultiselectComponent.prototype, "data", {
        set: function (value) {
            if (value) {
                // Remove duplicates
                this._data = value.filter(function (item, index, array) {
                    return array.map(function (obj) { return obj.text; }).indexOf(item.text) === index;
                });
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilMultiselectComponent.prototype, "limit", {
        set: function (value) {
            if (value) {
                this._limit = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilMultiselectComponent.prototype, "placeholder", {
        set: function (value) {
            if (value) {
                this._placeholder = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilMultiselectComponent.prototype, "listHeight", {
        set: function (value) {
            if (value) {
                this._listHeight = value;
            }
        },
        enumerable: true,
        configurable: true
    });
    VeilMultiselectComponent.prototype.toggleList = function () {
        this.isOpen = !this.isOpen;
    };
    VeilMultiselectComponent.prototype.onItemClick = function (clickedItem) {
        var found = this.selectedItems.find(function (item) { return item.text === clickedItem.text; });
        if (!found) {
            return this.addSelected(clickedItem);
        }
        this.removeSelected(clickedItem);
    };
    VeilMultiselectComponent.prototype.removeSelected = function (clickedItem) {
        this.selectedItems.forEach(function (item, index, array) {
            if (item.text === clickedItem.text) {
                array.splice(array.indexOf(item), 1);
            }
        });
        this.selected.emit(this.selectedItems.map(function (item) { return item.value; }));
    };
    VeilMultiselectComponent.prototype.isSelected = function (clickedItem) {
        return false || this.selectedItems.some(function (item) { return item.text === clickedItem.text; });
    };
    VeilMultiselectComponent.prototype.itemShowRemaining = function () {
        return this.selectedItems.length - this._limit;
    };
    VeilMultiselectComponent.prototype.addSelected = function (clickedItem) {
        this.selectedItems.push(clickedItem);
        this.selected.emit(this.selectedItems.map(function (item) { return item.value; }));
    };
    VeilMultiselectComponent.ctorParameters = function () { return [
        { type: Renderer2 }
    ]; };
    __decorate([
        ViewChild('inputGroup')
    ], VeilMultiselectComponent.prototype, "inputGroup", void 0);
    __decorate([
        ViewChild('list')
    ], VeilMultiselectComponent.prototype, "list", void 0);
    __decorate([
        Input()
    ], VeilMultiselectComponent.prototype, "data", null);
    __decorate([
        Input()
    ], VeilMultiselectComponent.prototype, "limit", null);
    __decorate([
        Input()
    ], VeilMultiselectComponent.prototype, "placeholder", null);
    __decorate([
        Input()
    ], VeilMultiselectComponent.prototype, "listHeight", null);
    __decorate([
        Output()
    ], VeilMultiselectComponent.prototype, "selected", void 0);
    VeilMultiselectComponent = __decorate([
        Component({
            selector: 'veil-multiselect',
            template: "<div class=\"select-field\" #inputGroup>\n  <span *ngIf=\"!selectedItems.length\" style=\"color: #545454\">{{ _placeholder }}</span>\n  <span class=\"badge\" *ngFor=\"let item of selectedItems; let i = index;\" [hidden]=\"i > _limit - 1\">\n    {{ item.text }}\n    <button type=\"button\" class=\"remove-btn\" (click)=\"removeSelected(item)\">\n      <i class=\"fa fa-times\" aria-hidden=\"true\"></i>\n    </button>\n  </span>\n  <span\n    style=\"margin-left: auto; margin-right: 10px;\"\n    *ngIf=\"itemShowRemaining() > 0\"\n  >\n    + {{ itemShowRemaining() }}\n  </span>\n  <button\n    type=\"button\"\n    class=\"dropdown-arrow\"\n    (click)=\"toggleList()\"\n  ></button>\n</div>\n<div class=\"dropdown-list\" *ngIf=\"isOpen\" #list [style.height]=\"_listHeight\">\n  <ul>\n    <li *ngFor=\"let item of _data\" (click)=\"onItemClick(item)\">\n      <div class=\"label\">\n        <input type=\"checkbox\" [checked]=\"isSelected(item)\">\n        <div class=\"custom-checkbox\"></div>\n        <span class=\"list-item-text\">{{ item.text }}</span>\n      </div>\n    </li>\n  </ul>\n</div>\n",
            styles: ["@charset \"UTF-8\";:host{display:block;position:relative}.select-field{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding:0 12px;height:30px;background-color:#f9f9f9;border:1px solid #e8e8e8;border-radius:2px;overflow:hidden;z-index:10}.badge{background-color:#1672a3;color:#fff;padding:1px 4px;border-radius:2px;margin-right:8px;white-space:nowrap}.remove-btn{color:inherit;border:none;background-color:transparent;margin-left:2px;cursor:pointer}.dropdown-arrow{position:absolute;width:20px;height:30px;right:0;text-align:center;background-color:#f9f9f9;border:none;cursor:pointer;outline:0;z-index:5}.dropdown-arrow:before{position:relative;right:0;top:11px;border-style:solid;border-width:5px 5px 0;border-color:#545454 transparent transparent;content:\"\"}.dropdown-list{padding-top:6px;width:100%;position:absolute;top:auto;margin-top:4px;border:1px solid #ccc;-webkit-box-shadow:0 .05rem .15rem rgba(140,140,140,.25);box-shadow:0 .05rem .15rem rgba(140,140,140,.25);border-radius:2px;background-color:#fff;z-index:1000;overflow-y:auto}.dropdown-list ul{list-style:none}.dropdown-list ul li{padding:6px 10px;cursor:pointer}.dropdown-list ul li .label{cursor:inherit;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.dropdown-list ul li .label input[type=checkbox]{opacity:0;position:absolute}.dropdown-list ul li .label input[type=checkbox]:checked+.custom-checkbox:after{content:\"\u2714\";background-color:#1672a3}.dropdown-list ul li .label .custom-checkbox{position:relative;height:calc(.7rem + 1px);width:calc(.7rem + 1px);border:1px solid #1672a3;margin-right:4px;border-radius:2px}.dropdown-list ul li .label .custom-checkbox:after{height:.7rem;width:.7rem;font-size:110%;position:absolute;top:0;left:0;content:\"\";-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;display:-webkit-box;display:-ms-flexbox;display:flex;color:#fff}"]
        })
    ], VeilMultiselectComponent);
    return VeilMultiselectComponent;
}());

var VeilMultiselectModule = /** @class */ (function () {
    function VeilMultiselectModule() {
    }
    VeilMultiselectModule = __decorate([
        NgModule({
            exports: [
                VeilMultiselectComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilMultiselectComponent
            ],
        })
    ], VeilMultiselectModule);
    return VeilMultiselectModule;
}());

var VeilPaginatorComponent = /** @class */ (function () {
    function VeilPaginatorComponent() {
        /*
         * Current pages displayed on UI
         */
        this.navPages = [];
        /*
         * Total items length
         */
        this.pagesCount = 0;
        /*
         * An array containing all pages
         */
        this.initPages = [];
        /*
         * Default start page
         */
        this.selectedPage = 1;
        this.langConfig = {
            prev: 'Previous',
            next: 'Next',
            shown: 'Shown',
            from: 'from'
        };
        this.pageChange = new EventEmitter();
    }
    VeilPaginatorComponent.prototype.ngOnChanges = function () {
        if (this.itemsCount && this.limit) {
            this.pagesCount = Math.ceil(this.itemsCount / this.limit);
        }
        this.initPages = new Array(this.pagesCount).fill(0).map(function (_, index) { return index + 1; });
        this.navPages = this.trimNavigation(this.initPages, this.selectedPage);
        this.updateOffsetInfo();
    };
    VeilPaginatorComponent.prototype.onChangePage = function (page) {
        this.selectedPage = page;
        this.navPages = this.trimNavigation(this.initPages, page);
        this.updateOffsetInfo();
        this.pageChange.emit(this.selectedPage);
    };
    VeilPaginatorComponent.prototype.onPrevPage = function () {
        if (this.selectedPage > 1) {
            this.selectedPage -= 1;
            this.onChangePage(this.selectedPage);
        }
    };
    VeilPaginatorComponent.prototype.onNextPage = function () {
        if (this.selectedPage < this.initPages.length) {
            this.selectedPage += 1;
            this.onChangePage(this.selectedPage);
        }
    };
    VeilPaginatorComponent.prototype.isFirstPage = function () {
        if (this.selectedPage === 1) {
            return true;
        }
        return false;
    };
    VeilPaginatorComponent.prototype.isLastPage = function () {
        if (this.selectedPage === this.initPages.length) {
            return true;
        }
        return false;
    };
    VeilPaginatorComponent.prototype.updateOffsetInfo = function () {
        var startItem = 1 + this.limit * (this.selectedPage - 1);
        var endItem = this.limit * this.selectedPage > this.itemsCount ? this.itemsCount : this.limit * this.selectedPage;
        if (startItem === endItem) {
            return this.offsetInfo = this.langConfig.shown + " " + startItem + " " + this.langConfig.from + " " + this.itemsCount;
        }
        this.offsetInfo = this.langConfig.shown + " " + startItem + "-" + endItem + " " + this.langConfig.from + " " + this.itemsCount;
    };
    VeilPaginatorComponent.prototype.trimNavigation = function (pages, selectedPage) {
        if (selectedPage < 3) {
            return pages.slice(0, 5);
        }
        if (selectedPage + 3 > pages.length) {
            return pages.slice(-5);
        }
        return pages.slice(selectedPage - 3, selectedPage + 2);
    };
    __decorate([
        Input()
    ], VeilPaginatorComponent.prototype, "selectedPage", void 0);
    __decorate([
        Input()
    ], VeilPaginatorComponent.prototype, "langConfig", void 0);
    __decorate([
        Input()
    ], VeilPaginatorComponent.prototype, "itemsCount", void 0);
    __decorate([
        Input()
    ], VeilPaginatorComponent.prototype, "limit", void 0);
    __decorate([
        Input()
    ], VeilPaginatorComponent.prototype, "navDisabled", void 0);
    __decorate([
        Output()
    ], VeilPaginatorComponent.prototype, "pageChange", void 0);
    VeilPaginatorComponent = __decorate([
        Component({
            selector: 'veil-paginator',
            template: "<ng-content></ng-content>\n<div class=\"wrapper\" *ngIf=\"pagesCount\">\n  <div class=\"paginator-controls\">\n    <button (click)=\"onPrevPage()\" [disabled]=\"isFirstPage() || navDisabled\">\n      <i class=\"fa fa-chevron-circle-left\" aria-hidden=\"true\"></i>\n      {{ langConfig.prev }}\n    </button>\n    <ul>\n      <li *ngFor=\"let page of navPages\">\n        <button\n          [ngClass]=\"{ active: page === selectedPage}\"\n          (click)=\"onChangePage(page)\"\n          [disabled]=\"navDisabled\"\n        >\n          {{ page }}\n        </button>\n      </li>\n    </ul>\n    <button (click)=\"onNextPage()\" [disabled]=\"isLastPage() || navDisabled\">\n      {{ langConfig.next }}\n      <i class=\"fa fa-chevron-circle-right\" aria-hidden=\"true\"></i>\n    </button>\n  </div>\n  <div class=\"paginator-info\">{{ offsetInfo }}</div>\n</div>\n",
            styles: [":host{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:inherit}:host ::ng-deep veil-table{display:contents}.wrapper{display:-webkit-box;display:-ms-flexbox;display:flex;color:rgba(0,0,0,.5);border-top:1px solid #dedede}.wrapper .paginator-controls{display:-webkit-box;display:-ms-flexbox;display:flex}.wrapper .paginator-controls button{color:inherit;border-top:2px solid transparent;border-bottom:2px solid transparent;border-right:none;border-left:none;background-color:transparent;padding:.3rem;outline:0;cursor:pointer}.wrapper .paginator-controls button:hover{background-color:#535f59;color:#fff}.wrapper .paginator-controls button.active{border-bottom-color:#535f59;font-weight:700;background-color:initial;color:rgba(0,0,0,.5);cursor:default}.wrapper .paginator-controls button:disabled{background-color:transparent!important;color:rgba(0,0,0,.3);cursor:default}.wrapper .paginator-controls ul{display:inherit;list-style:none;margin:0 .2rem}.wrapper .paginator-info{margin-left:auto;padding:calc(.3rem + 2px)}"]
        })
    ], VeilPaginatorComponent);
    return VeilPaginatorComponent;
}());

var VeilPaginatorModule = /** @class */ (function () {
    function VeilPaginatorModule() {
    }
    VeilPaginatorModule = __decorate([
        NgModule({
            exports: [
                VeilPaginatorComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilPaginatorComponent
            ],
        })
    ], VeilPaginatorModule);
    return VeilPaginatorModule;
}());

var TIME_REGEX = /^(0[0-9]|1[0-9]|2[0-3]):[0-5][0-9]$/;

function timeIsValid(time) {
    return TIME_REGEX.test(time);
}

var VeilTimepickerComponent = /** @class */ (function () {
    function VeilTimepickerComponent(renderer) {
        var _this = this;
        this.renderer = renderer;
        this.clockFaceIsOpen = false;
        this.hours = new Array(24).fill(0).map(function (_, index) { return format(index); });
        this.minutes = new Array(60).fill(0).map(function (_, index) { return format(index); });
        this.date = new Date();
        this.update = new EventEmitter();
        this.renderer.listen('document', 'click', function (evt) {
            if (!_this.inputGroup.nativeElement.contains(evt.target) &&
                !_this.clockface.nativeElement.contains(evt.target)) {
                _this.hideClockFace();
            }
        });
    }
    VeilTimepickerComponent.prototype.ngOnInit = function () {
        this.selectedHour = this.date.getHours();
        this.selectedMinute = this.date.getMinutes();
        this.updateHours();
        this.updateMinutes();
    };
    VeilTimepickerComponent.prototype.toggleClockFace = function () {
        this.clockFaceIsOpen = !this.clockFaceIsOpen;
        if (this.clockFaceIsOpen && timeIsValid(this.inputTime)) {
            var _a = __read(this.inputTime.split(':'), 2), hour = _a[0], minute = _a[1];
            this.selectedHour = +hour;
            this.selectedMinute = +minute;
            this.updateHours();
            this.updateMinutes();
        }
    };
    VeilTimepickerComponent.prototype.hideClockFace = function () {
        this.clockFaceIsOpen = false;
    };
    VeilTimepickerComponent.prototype.inputChange = function (evt) {
        if (timeIsValid(this.inputTime)) {
            this.update.emit(this.inputTime);
        }
    };
    /*
     *  As the second parameter method takes a type ('selectedHour' or 'selectedMinute').
     *  Using the type, we change the value of the corresponding property.
     *  Finally, we call updateHours or updateMinutes method.
     */
    VeilTimepickerComponent.prototype.onMouseWheel = function (evt, type) {
        if (evt.deltaY > 0) {
            this[type] += 1;
        }
        else {
            this[type] -= 1;
        }
        this["update" + type.slice(8) + "s"]();
    };
    VeilTimepickerComponent.prototype.setHour = function (hour) {
        this.selectedHour = +hour;
        this.updateHours();
    };
    VeilTimepickerComponent.prototype.setMinute = function (minute) {
        this.selectedMinute = +minute;
        this.updateMinutes();
    };
    VeilTimepickerComponent.prototype.confirmTime = function () {
        this.inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
        this.hideClockFace();
        this.update.emit(this.inputTime);
    };
    VeilTimepickerComponent.prototype.updateHours = function () {
        if (this.selectedHour === 0 || this.selectedHour === 24) {
            this.selectedHour = 0;
            return this.trimmedHours = __spread(['23'], this.hours).slice(0, 3);
        }
        if (this.selectedHour === -1 || this.selectedHour === 23) {
            this.selectedHour = 23;
            return this.trimmedHours = __spread(this.hours, ['00']).slice(this.selectedHour - 1, this.selectedHour + 2);
        }
        this.trimmedHours = this.hours.slice(this.selectedHour - 1, this.selectedHour + 2);
    };
    VeilTimepickerComponent.prototype.updateMinutes = function () {
        if (this.selectedMinute === 0 || this.selectedMinute === 60) {
            this.selectedMinute = 0;
            return this.trimmedMinutes = __spread(['59'], this.minutes).slice(0, 3);
        }
        if (this.selectedMinute === -1 || this.selectedMinute === 59) {
            this.selectedMinute = 59;
            return this.trimmedMinutes = __spread(this.minutes, ['00']).slice(this.selectedMinute - 1, this.selectedMinute + 2);
        }
        this.trimmedMinutes = this.minutes.slice(this.selectedMinute - 1, this.selectedMinute + 2);
    };
    VeilTimepickerComponent.ctorParameters = function () { return [
        { type: Renderer2 }
    ]; };
    __decorate([
        ViewChild('inputGroup')
    ], VeilTimepickerComponent.prototype, "inputGroup", void 0);
    __decorate([
        ViewChild('clockFace')
    ], VeilTimepickerComponent.prototype, "clockface", void 0);
    __decorate([
        Output()
    ], VeilTimepickerComponent.prototype, "update", void 0);
    VeilTimepickerComponent = __decorate([
        Component({
            selector: 'veil-timepicker',
            template: "<div class=\"input-group\" #inputGroup>\n  <input\n    type=\"text\"\n    maxlength=\"5\"\n    [(ngModel)]=\"inputTime\"\n    (ngModelChange)=\"inputChange($event)\"\n    (click)=\"hideClockFace()\"\n    (focus)=\"hideClockFace()\"\n  >\n  <button (click)=\"toggleClockFace()\" type=\"button\">\n    <i class=\"fa fa-clock-o\" aria-hidden=\"true\"></i>\n  </button>\n</div>\n<div #clockFace>\n  <div *ngIf=\"clockFaceIsOpen\" class=\"clock-face\">\n    <div class=\"wrapper\">\n      <table class=\"hours\" (wheel)=\"onMouseWheel($event, 'selectedHour')\">\n        <tr *ngFor=\"let hour of trimmedHours; let i = index\">\n          <td>\n            <button\n              [ngClass]=\"{ active: i === 1 }\"\n              (click)=\"setHour(hour)\"\n              type=\"button\"\n            >\n              {{ hour }}\n            </button>\n          </td>\n        </tr>\n      </table>\n      <table class=\"minutes\" (wheel)=\"onMouseWheel($event, 'selectedMinute')\">\n        <tr *ngFor=\"let minute of trimmedMinutes; let i = index\">\n          <td>\n            <button\n              [ngClass]=\"{ active: i === 1 }\"\n              (click)=\"setMinute(minute)\"\n              type=\"button\"\n            >\n              {{ minute }}\n            </button>\n          </td>\n        </tr>\n      </table>\n    </div>\n    <div class=\"controls\">\n      <button (click)=\"confirmTime()\" type=\"button\">OK</button>\n    </div>\n  </div>\n</div>\n",
            styles: [":host{position:relative;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}button{outline:0}.input-group{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-width:14rem}.input-group input{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex:1;-ms-flex:1;flex:1;height:30px;background-color:#f9f9f9;padding-left:12px;padding-right:30px;border:1px solid #e8e8e8;border-radius:2px}.input-group button{border:none;font-size:1rem;background:0 0;position:absolute;right:8px;cursor:pointer;color:#1672a3}.clock-face{min-width:7rem;position:absolute;top:auto;right:0;background-color:#fff;padding:.6rem;margin-top:4px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;border:1px solid #ccc;border-radius:2px;-webkit-box-shadow:0 .05rem .15rem rgba(140,140,140,.25);box-shadow:0 .05rem .15rem rgba(140,140,140,.25);z-index:9999}.clock-face .wrapper{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.clock-face .wrapper .hours tr:nth-child(2) td,.clock-face .wrapper .minutes tr:nth-child(2) td{border-top:1px solid #9a9a9a;border-bottom:1px solid #9a9a9a}.clock-face .wrapper .hours tr:nth-child(2) td{position:relative}.clock-face .wrapper .hours tr:nth-child(2) td:after{content:\":\";display:inline;position:absolute;font-size:1.1rem;color:#1672a3;top:.2rem}.clock-face .wrapper button{height:1.8rem;min-width:1.8rem;padding:0;margin:0;border:none;border-radius:.15rem;background:0 0;width:100%;color:inherit}.clock-face .wrapper button.active{font-size:1.1rem;color:#1672a3}.clock-face .wrapper button:not(.active){cursor:pointer}.clock-face .wrapper button:hover{color:#1672a3}.clock-face .controls{text-align:center;padding-top:.6rem}.clock-face .controls button{font-family:inherit;border-radius:.25rem;padding:.3rem;outline:0;background-color:#0072a3;color:#fff;border:none;cursor:pointer}.clock-face .controls button:hover{background-color:#00567a;color:#daebf7}"]
        })
    ], VeilTimepickerComponent);
    return VeilTimepickerComponent;
}());

var VeilTimepickerModule = /** @class */ (function () {
    function VeilTimepickerModule() {
    }
    VeilTimepickerModule = __decorate([
        NgModule({
            exports: [
                VeilTimepickerComponent
            ],
            imports: [
                CommonModule,
                FormsModule
            ],
            declarations: [
                VeilTimepickerComponent
            ],
        })
    ], VeilTimepickerModule);
    return VeilTimepickerModule;
}());

var VeilDatetimepickerComponent = /** @class */ (function () {
    function VeilDatetimepickerComponent(renderer) {
        var _this = this;
        this.renderer = renderer;
        this.inputDateTime = '';
        this.date = new Date();
        this.pickerIsOpen = false;
        this.confirmDisabled = true;
        this.hours = new Array(24).fill(0).map(function (_, index) { return format(index); });
        this.minutes = new Array(60).fill(0).map(function (_, index) { return format(index); });
        this.update = new EventEmitter();
        this.renderer.listen('document', 'click', function (evt) {
            var element = evt.target;
            if (!_this.inputGroup.nativeElement.contains(evt.target) &&
                !_this.picker.nativeElement.contains(evt.target) &&
                !element.className.includes('day-btn')) {
                _this.hidePicker();
            }
        });
        this.weekNarrow = weekNarrow;
        this.months = months;
    }
    VeilDatetimepickerComponent.prototype.ngOnInit = function () {
        this.selectedHour = this.date.getHours();
        this.selectedMinute = this.date.getMinutes();
    };
    VeilDatetimepickerComponent.prototype.inputChange = function (evt) {
        this.selectedDate = new Date();
        var _a = __read(this.inputDateTime.split(' '), 2), date = _a[0], time = _a[1];
        if (dateIsValid(date) && timeIsValid(time)) {
            this.update.emit(this.inputDateTime);
        }
    };
    VeilDatetimepickerComponent.prototype.togglePicker = function () {
        this.pickerIsOpen = !this.pickerIsOpen;
        this.month = this.date.getMonth();
        this.year = this.date.getFullYear();
        this.selectedDate = null;
        this.confirmDisabled = true;
        this._inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
        var _a = __read(this.inputDateTime.split(' '), 2), date = _a[0], time = _a[1];
        if (this.pickerIsOpen && dateIsValid(date)) {
            this.confirmDisabled = false;
            this._inputDate = date;
            this.selectedDate = new Date(date.replace(/-/g, '/').split('/').reverse().join('-'));
            this.year = this.selectedDate.getFullYear();
            this.month = this.selectedDate.getMonth();
        }
        this.initCalendarView();
        if (this.pickerIsOpen && timeIsValid(time)) {
            var _b = __read(time.split(':'), 2), hour = _b[0], minute = _b[1];
            this.selectedHour = +hour;
            this.selectedMinute = +minute;
            this._inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
        }
        this.updateHours();
        this.updateMinutes();
    };
    VeilDatetimepickerComponent.prototype.hidePicker = function () {
        this.pickerIsOpen = false;
    };
    VeilDatetimepickerComponent.prototype.confirm = function () {
        this.hidePicker();
        this.inputDateTime = this._inputDate + " " + this._inputTime;
        this.update.emit(this.inputDateTime);
    };
    // Calendar methods
    VeilDatetimepickerComponent.prototype.updateMonth = function (route) {
        switch (route) {
            case 'prev':
                this.month--;
                break;
            case 'next':
                this.month++;
                break;
            default:
                this.month = this.date.getMonth();
                this.year = this.date.getFullYear();
        }
        if (this.month < 0) {
            this.month = 11;
            this.year--;
        }
        if (this.month > 11) {
            this.month = 0;
            this.year++;
        }
        this.initCalendarView();
    };
    VeilDatetimepickerComponent.prototype.selectDay = function (day) {
        this.confirmDisabled = false;
        var inputDate = format(day.num) + "/" + format(day.month + 1) + "/" + this.year;
        this._inputDate = inputDate;
        this.selectedDate = new Date(inputDate.replace(/-/g, '/').split('/').reverse().join('-'));
        this.initCalendarView();
    };
    VeilDatetimepickerComponent.prototype.getMonthData = function (month) {
        var _this = this;
        var days = getNumberOfDaysInTheMonth(this.year, month);
        return new Array(days).fill({}).map(function (_, index) {
            var status = _this.getStatus(index + 1, month);
            return {
                num: index + 1,
                month: month,
                status: status
            };
        });
    };
    VeilDatetimepickerComponent.prototype.getStatus = function (day, month) {
        if (month !== this.month && this.isSelected(day, month)) {
            return 'excluded selected';
        }
        if (month !== this.month) {
            return 'excluded';
        }
        if (this.isToday(day) && this.isSelected(day, month)) {
            return 'today selected';
        }
        if (this.isToday(day)) {
            return 'today';
        }
        if (this.isSelected(day, month)) {
            return 'selected';
        }
        return '';
    };
    VeilDatetimepickerComponent.prototype.isToday = function (day) {
        if (datesAreEqual(day, this.month, this.year, this.date)) {
            return true;
        }
        return false;
    };
    VeilDatetimepickerComponent.prototype.isSelected = function (day, month) {
        if (this.selectedDate &&
            datesAreEqual(day, month, this.year, this.selectedDate)) {
            return true;
        }
        return false;
    };
    VeilDatetimepickerComponent.prototype.initCalendarView = function () {
        var previousMonthEndDate = new Date(this.year, this.month, 0);
        var dayOfWeek = previousMonthEndDate.getDay();
        if (dayOfWeek === 0) {
            dayOfWeek = 7;
        }
        var days = __spread(this.getMonthData(this.month - 1).slice(-dayOfWeek), this.getMonthData(this.month), this.getMonthData(this.month + 1)).slice(0, 42);
        // Here we split the array into an array of arrays on 7 days for convenient display on UI
        this.calendarView = days.reduce(function (res, day) {
            if (res[res.length - 1].length === 7) {
                res.push([]);
            }
            res[res.length - 1].push(day);
            return res;
        }, [[]]);
    };
    // Timepicker methods
    /*
     *  As the second parameter method takes a type ('selectedHour' or 'selectedMinute').
     *  Using the type, we change the value of the corresponding property.
     *  Finally, we call updateHours or updateMinutes method.
     */
    VeilDatetimepickerComponent.prototype.onMouseWheel = function (evt, type) {
        if (evt.deltaY > 0) {
            this[type] += 1;
        }
        else {
            this[type] -= 1;
        }
        this["update" + type.slice(8) + "s"]();
        this._inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
    };
    VeilDatetimepickerComponent.prototype.setHour = function (hour) {
        this.selectedHour = +hour;
        this.updateHours();
        this._inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
    };
    VeilDatetimepickerComponent.prototype.setMinute = function (minute) {
        this.selectedMinute = +minute;
        this.updateMinutes();
        this._inputTime = format(this.selectedHour) + ":" + format(this.selectedMinute);
    };
    VeilDatetimepickerComponent.prototype.updateHours = function () {
        if (this.selectedHour === 0 || this.selectedHour === 24) {
            this.selectedHour = 0;
            return this.trimmedHours = __spread(['23'], this.hours).slice(0, 3);
        }
        if (this.selectedHour === -1 || this.selectedHour === 23) {
            this.selectedHour = 23;
            return this.trimmedHours = __spread(this.hours, ['00']).slice(this.selectedHour - 1, this.selectedHour + 2);
        }
        this.trimmedHours = this.hours.slice(this.selectedHour - 1, this.selectedHour + 2);
    };
    VeilDatetimepickerComponent.prototype.updateMinutes = function () {
        if (this.selectedMinute === 0 || this.selectedMinute === 60) {
            this.selectedMinute = 0;
            return this.trimmedMinutes = __spread(['59'], this.minutes).slice(0, 3);
        }
        if (this.selectedMinute === -1 || this.selectedMinute === 59) {
            this.selectedMinute = 59;
            return this.trimmedMinutes = __spread(this.minutes, ['00']).slice(this.selectedMinute - 1, this.selectedMinute + 2);
        }
        this.trimmedMinutes = this.minutes.slice(this.selectedMinute - 1, this.selectedMinute + 2);
    };
    VeilDatetimepickerComponent.ctorParameters = function () { return [
        { type: Renderer2 }
    ]; };
    __decorate([
        ViewChild('inputGroup')
    ], VeilDatetimepickerComponent.prototype, "inputGroup", void 0);
    __decorate([
        ViewChild('picker')
    ], VeilDatetimepickerComponent.prototype, "picker", void 0);
    __decorate([
        Output()
    ], VeilDatetimepickerComponent.prototype, "update", void 0);
    VeilDatetimepickerComponent = __decorate([
        Component({
            selector: 'veil-datetimepicker',
            template: "<div class=\"input-group\" #inputGroup>\n  <input\n    type=\"text\"\n    placeholder=\"\u0412\u044B\u0431\u0435\u0440\u0438\u0442\u0435 \u0434\u0430\u0442\u0443\"\n    [(ngModel)]=\"inputDateTime\"\n    (ngModelChange)=\"inputChange($event)\"\n    (click)=\"hidePicker()\"\n    (focus)=\"hidePicker()\"\n  >\n  <button type=\"button\" (click)=\"togglePicker()\">\n    <i class=\"fa fa-calendar\" aria-hidden=\"true\"></i>\n  </button>\n</div>\n<div #picker>\n  <div *ngIf=\"pickerIsOpen\" class=\"picker\">\n    <div class=\"calendar\">\n      <div class=\"table-header\">\n        <span>{{ months[month] }} {{ year }}</span>\n        <div class=\"controls\">\n          <button type=\"button\" (click)=\"updateMonth('prev')\">\n            <i class=\"fa fa-angle-left\" aria-hidden=\"true\"></i>\n          </button>\n          <button type=\"button\" (click)=\"updateMonth()\">\n            <i class=\"fa fa-calendar-check-o\" aria-hidden=\"true\"></i>\n          </button>\n          <button type=\"button\" (click)=\"updateMonth('next')\">\n            <i class=\"fa fa-angle-right\" aria-hidden=\"true\"></i>\n          </button>\n        </div>\n      </div>\n      <table>\n        <tr>\n          <th *ngFor=\"let day of weekNarrow\" class=\"calendar-cell\">{{ day }}</th>\n        </tr>\n        <tr *ngFor=\"let row of calendarView\">\n          <td *ngFor=\"let day of row\">\n            <button\n              type=\"button\"\n              class=\"day-btn\"\n              ngClass=\"{{ day.status }}\"\n              (click)=\"selectDay(day)\"\n            >\n              {{ day.num }}\n            </button>\n          </td>\n        </tr>\n      </table>\n    </div>\n    <div class=\"clock-face\">\n      <div class=\"wrapper\">\n        <table class=\"hours\" (wheel)=\"onMouseWheel($event, 'selectedHour')\">\n          <tr *ngFor=\"let hour of trimmedHours; let i = index\">\n            <td>\n              <button\n                [ngClass]=\"{ active: i === 1 }\"\n                (click)=\"setHour(hour)\"\n                type=\"button\"\n              >\n                {{ hour }}\n              </button>\n            </td>\n          </tr>\n        </table>\n        <table class=\"minutes\" (wheel)=\"onMouseWheel($event, 'selectedMinute')\">\n          <tr *ngFor=\"let minute of trimmedMinutes; let i = index\">\n            <td>\n              <button\n                [ngClass]=\"{ active: i === 1 }\"\n                (click)=\"setMinute(minute)\"\n                type=\"button\"\n              >\n                {{ minute }}\n              </button>\n            </td>\n          </tr>\n        </table>\n      </div>\n      <div class=\"controls\">\n        <button (click)=\"confirm()\" type=\"button\" [disabled]=\"confirmDisabled\">OK</button>\n      </div>\n    </div>\n  </div>\n</div>\n",
            styles: [":host{position:relative;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}button{outline:0}.input-group{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-width:14rem}.input-group input{position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-flex:1;-ms-flex:1;flex:1;height:30px;background-color:#f9f9f9;padding-left:12px;padding-right:30px;border:1px solid #e8e8e8;border-radius:2px}.input-group button{border:none;font-size:1rem;background:0 0;position:absolute;right:8px;cursor:pointer;color:#1672a3}.picker{position:absolute;top:auto;right:0;margin-top:4px;-webkit-box-shadow:0 .05rem .15rem rgba(140,140,140,.25);box-shadow:0 .05rem .15rem rgba(140,140,140,.25)}.calendar{background-color:#fff;padding:.6rem;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;border:1px solid #ccc;border-top-right-radius:2px;border-top-left-radius:2px;z-index:9999}.calendar .table-header{font-size:.9rem;padding:.3rem;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:#1672a3}.calendar .table-header .controls button{border:0;background:0 0;padding:.3rem;border-radius:.15rem;cursor:pointer;color:inherit}.calendar .table-header .controls button:hover{background-color:#e8e8e8}.calendar table{border-spacing:0}.calendar .calendar-cell{height:1.8rem;width:1.8rem;min-height:1.8rem;min-width:1.8rem;padding:0;text-align:center;color:#666}.calendar .day-btn{height:1.8rem;min-width:1.8rem;padding:0;margin:0;border:none;border-radius:.15rem;background:0 0;cursor:pointer;width:100%;color:inherit}.calendar .day-btn:hover{background:#e8e8e8}.calendar .day-btn.excluded{opacity:.4}.calendar .day-btn.excluded.selected{background:0 0;border:1px solid #000}.calendar .day-btn.excluded:hover{background:0 0}.calendar .day-btn.today{font-weight:600;color:#000}.calendar .day-btn.selected{background:#d8e3e9;color:#000}.clock-face{width:100%;background-color:#fff;padding:.6rem;border:1px solid #ccc;border-top:none;border-bottom-right-radius:2px;border-bottom-left-radius:2px;z-index:9999}.clock-face .wrapper{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center}.clock-face .wrapper .hours tr:nth-child(2) td,.clock-face .wrapper .minutes tr:nth-child(2) td{border-top:1px solid #9a9a9a;border-bottom:1px solid #9a9a9a}.clock-face .wrapper .hours tr:nth-child(2) td{position:relative}.clock-face .wrapper .hours tr:nth-child(2) td:after{content:\":\";display:inline;position:absolute;font-size:1.1rem;color:#1672a3;top:.2rem}.clock-face .wrapper button{height:1.8rem;min-width:1.8rem;padding:0;margin:0;border:none;border-radius:.15rem;background:0 0;width:100%;color:inherit}.clock-face .wrapper button.active{font-size:1.1rem;color:#1672a3}.clock-face .wrapper button:not(.active){cursor:pointer}.clock-face .wrapper button:hover{color:#1672a3}.clock-face .controls{text-align:center;padding-top:.6rem}.clock-face .controls button{font-family:inherit;border-radius:.25rem;padding:.3rem 1rem;outline:0;background-color:#0072a3;color:#fff;border:none;cursor:pointer}.clock-face .controls button:hover{background-color:#00567a;color:#daebf7}.clock-face .controls button:disabled{cursor:default;opacity:.6;background-color:#0072a3!important}"]
        })
    ], VeilDatetimepickerComponent);
    return VeilDatetimepickerComponent;
}());

var VeilDatetimepickerModule = /** @class */ (function () {
    function VeilDatetimepickerModule() {
    }
    VeilDatetimepickerModule = __decorate([
        NgModule({
            exports: [
                VeilDatetimepickerComponent
            ],
            imports: [
                CommonModule,
                FormsModule
            ],
            declarations: [
                VeilDatetimepickerComponent
            ],
        })
    ], VeilDatetimepickerModule);
    return VeilDatetimepickerModule;
}());

var VeilBadgeComponent = /** @class */ (function () {
    function VeilBadgeComponent(element, renderer) {
        this.element = element;
        this.renderer = renderer;
        this._limit = false;
    }
    Object.defineProperty(VeilBadgeComponent.prototype, "limit", {
        set: function (_) {
            this._limit = true;
        },
        enumerable: true,
        configurable: true
    });
    VeilBadgeComponent.prototype.ngDoCheck = function () {
        var nodesLength = this.element.nativeElement.childNodes.length;
        var node = this.element.nativeElement.childNodes[0];
        if (this._limit &&
            nodesLength === 1 &&
            !isNaN(Number.parseInt(node.textContent, 10)) &&
            node.textContent > 99) {
            this.renderer.setValue(node, '99+');
        }
    };
    VeilBadgeComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: Renderer2 }
    ]; };
    __decorate([
        Input()
    ], VeilBadgeComponent.prototype, "limit", null);
    VeilBadgeComponent = __decorate([
        Component({
            selector: 'veil-badge',
            template: '<ng-content></ng-content>',
            styles: [":host{display:-webkit-inline-box;display:-ms-inline-flexbox;display:inline-flex;vertical-align:middle;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;min-width:.75rem;background:#8c8c8c;color:#fff;height:.75rem;line-height:normal;border-radius:.5rem;font-size:75%;font-weight:700;padding:0 .2rem;margin-right:.3rem;white-space:nowrap;text-align:center}:host[status=info]{background:#0072a3}:host[status=danger]{background:#db2100}:host[status=warning]{background:#fa0;color:#474747}:host[status=success]{background:#3c8500}"]
        })
    ], VeilBadgeComponent);
    return VeilBadgeComponent;
}());

var VeilBadgeModule = /** @class */ (function () {
    function VeilBadgeModule() {
    }
    VeilBadgeModule = __decorate([
        NgModule({
            exports: [
                VeilBadgeComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilBadgeComponent
            ],
        })
    ], VeilBadgeModule);
    return VeilBadgeModule;
}());

var VeilProgressBarComponent = /** @class */ (function () {
    function VeilProgressBarComponent() {
        /*
         * Progress
         */
        this._value = '0%';
        /*
         * Showing current value on the progress bar
         */
        this._labeled = false;
    }
    Object.defineProperty(VeilProgressBarComponent.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (value) {
            if (+value > 100) {
                this._value = '100%';
            }
            else {
                this._value = value + "%";
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilProgressBarComponent.prototype, "labeled", {
        get: function () {
            return this._labeled;
        },
        set: function (_) {
            this._labeled = true;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        Input('value')
    ], VeilProgressBarComponent.prototype, "value", null);
    __decorate([
        Input('labeled')
    ], VeilProgressBarComponent.prototype, "labeled", null);
    VeilProgressBarComponent = __decorate([
        Component({
            selector: 'veil-progress-bar',
            template: "\n    <div [style.width]=\"value\" class=\"progress-bar\" role=\"progressbar\">\n      <span *ngIf=\"labeled\">{{ value }}</span>\n    </div>\n  ",
            styles: [":host{display:-webkit-box;display:-ms-flexbox;display:flex;height:1rem;overflow:hidden;font-weight:700;background-color:#e9ecef;border-radius:.25rem}:host .progress-bar{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#fff;text-align:center;background-color:#007bff;-webkit-transition:width .6s;transition:width .6s}:host .progress-bar span{text-shadow:0 0 2px rgba(0,0,0,.5)}:host[striped] .progress-bar{background-image:linear-gradient(45deg,rgba(255,255,255,.15) 25%,transparent 25%,transparent 50%,rgba(255,255,255,.15) 50%,rgba(255,255,255,.15) 75%,transparent 75%,transparent);background-size:1rem 1rem}:host[status=success] .progress-bar{background-color:#3c8500}:host[status=warning] .progress-bar{background-color:#fa0}:host[status=danger] .progress-bar{background-color:#db2100}"]
        })
    ], VeilProgressBarComponent);
    return VeilProgressBarComponent;
}());

var VeilProgressBarModule = /** @class */ (function () {
    function VeilProgressBarModule() {
    }
    VeilProgressBarModule = __decorate([
        NgModule({
            exports: [
                VeilProgressBarComponent
            ],
            imports: [
                CommonModule
            ],
            declarations: [
                VeilProgressBarComponent
            ],
        })
    ], VeilProgressBarModule);
    return VeilProgressBarModule;
}());

var StepperService = /** @class */ (function () {
    function StepperService() {
        this.activeStep = new Subject();
        this.activeStepError = new Subject();
    }
    StepperService.prototype.navigateToNextStep = function (currentStepId, currentPanelValid) {
        if (currentPanelValid === void 0) { currentPanelValid = true; }
        if (currentPanelValid) {
            this.activeStepError.next(false);
            if (this.steps.indexOf(currentStepId) !== this.steps.length - 1) {
                this.activeStep.next(this.steps.indexOf(currentStepId) + 1);
            }
        }
        else {
            this.activeStepError.next(true);
        }
    };
    StepperService.prototype.navigateToStep = function (index) {
        this.activeStep.next(index);
    };
    StepperService.prototype.isActiveStep = function (stepId, data) {
        return this.steps[data] === stepId;
    };
    StepperService.prototype.getActiveStep = function () {
        return this.activeStep;
    };
    StepperService.prototype.getActiveStepError = function () {
        return this.activeStepError;
    };
    StepperService.prototype.setSteps = function (queryList) {
        this.steps = queryList.toArray().map(function (p) { return p.id; });
        this.activeStep.next(0); // Init first step
    };
    StepperService = __decorate([
        Injectable()
    ], StepperService);
    return StepperService;
}());

var VeilStepperStepComponent = /** @class */ (function () {
    function VeilStepperStepComponent(formGroupName, ngModelGroup, stepperService) {
        this.formGroupName = formGroupName;
        this.ngModelGroup = ngModelGroup;
        this.stepperService = stepperService;
        this.subscriptions = [];
        this.isActiveStep = false;
        this.isErrored = false;
    }
    Object.defineProperty(VeilStepperStepComponent.prototype, "formGroup", {
        get: function () {
            return this.formGroupName ? this.formGroupName.control : this.ngModelGroup.control;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(VeilStepperStepComponent.prototype, "id", {
        get: function () {
            return this.formGroupName ? this.formGroupName.name.toString() : this.ngModelGroup.name;
        },
        set: function (_value) {
            // overriding parent id required empty setter
        },
        enumerable: true,
        configurable: true
    });
    VeilStepperStepComponent.prototype.ngOnInit = function () {
        this.subscriptions.push(this.listenForActiveStep());
        this.subscriptions.push(this.listenForActiveStepError());
    };
    VeilStepperStepComponent.prototype.ngOnDestroy = function () {
        this.subscriptions.forEach(function (s) { return s.unsubscribe(); });
    };
    VeilStepperStepComponent.prototype.listenForActiveStep = function () {
        var _this = this;
        return this.stepperService.getActiveStep().subscribe(function (data) {
            if (_this.stepperService.isActiveStep(_this.id, data)) {
                _this.isActiveStep = true;
            }
            else {
                _this.isActiveStep = false;
            }
        });
    };
    VeilStepperStepComponent.prototype.listenForActiveStepError = function () {
        var _this = this;
        return this.stepperService.getActiveStepError().subscribe(function (error) {
            if (_this.isActiveStep) {
                _this.isErrored = error;
            }
        });
    };
    VeilStepperStepComponent.ctorParameters = function () { return [
        { type: FormGroupName, decorators: [{ type: Optional }] },
        { type: NgModelGroup, decorators: [{ type: Optional }] },
        { type: StepperService }
    ]; };
    __decorate([
        HostBinding('class.active')
    ], VeilStepperStepComponent.prototype, "isActiveStep", void 0);
    __decorate([
        HostBinding('class.error')
    ], VeilStepperStepComponent.prototype, "isErrored", void 0);
    VeilStepperStepComponent = __decorate([
        Component({
            selector: 'veil-stepper-step',
            template: '<ng-content></ng-content>',
            styles: [":host{display:none}:host.active{display:block}:host.error ::ng-deep .header{border-bottom-color:#db2100}:host ::ng-deep .header{font-size:1rem;padding:.47rem;background-color:#d8e3e9;color:#666;border-bottom:1px solid transparent}"]
        }),
        __param(0, Optional()),
        __param(1, Optional())
    ], VeilStepperStepComponent);
    return VeilStepperStepComponent;
}());

var VeilStepperComponent = /** @class */ (function () {
    function VeilStepperComponent(formGroup, ngForm, stepperService) {
        this.formGroup = formGroup;
        this.ngForm = ngForm;
        this.stepperService = stepperService;
    }
    VeilStepperComponent.prototype.ngOnInit = function () {
        if (!this.formGroup && !this.ngForm) {
            throw new Error('To use stepper a Reactive or Template Form is required.');
        }
        this.form = this.formGroup ? this.formGroup : this.ngForm;
    };
    VeilStepperComponent.prototype.ngAfterContentInit = function () {
        this.stepperService.setSteps(this.steps);
    };
    VeilStepperComponent.ctorParameters = function () { return [
        { type: FormGroupDirective, decorators: [{ type: Optional }] },
        { type: NgForm, decorators: [{ type: Optional }] },
        { type: StepperService }
    ]; };
    __decorate([
        ContentChildren(VeilStepperStepComponent, { descendants: true })
    ], VeilStepperComponent.prototype, "steps", void 0);
    VeilStepperComponent = __decorate([
        Component({
            /* tslint:disable-next-line */
            selector: 'form[veilStepper]',
            template: '<ng-content></ng-content>',
            styles: [":host ::ng-deep .panel{border:1px solid #ccc;width:auto;display:-webkit-box;display:-ms-flexbox;display:flex}:host ::ng-deep .stepper-panel{width:100%}"]
        }),
        __param(0, Optional()),
        __param(1, Optional())
    ], VeilStepperComponent);
    return VeilStepperComponent;
}());

var VeilStepperNavComponent = /** @class */ (function () {
    function VeilStepperNavComponent(stepperService) {
        this.stepperService = stepperService;
        this.activeIndex = 0;
        this.subscriptions = [];
    }
    VeilStepperNavComponent.prototype.ngOnInit = function () {
        if (!this.navTitles) {
            throw new Error('<veil-stepper-nav> navTitles is required.');
        }
        this.erroredArray = new Array(this.navTitles.length).fill(false);
        this.successArray = new Array(this.navTitles.length).fill(false);
        this.subscriptions.push(this.listenForActiveStep());
        this.subscriptions.push(this.listenForActiveStepError());
    };
    VeilStepperNavComponent.prototype.ngOnDestroy = function () {
        this.subscriptions.forEach(function (s) { return s.unsubscribe(); });
    };
    VeilStepperNavComponent.prototype.isErrored = function (index) {
        return this.erroredArray[index];
    };
    VeilStepperNavComponent.prototype.isSuccess = function (index) {
        return this.successArray[index];
    };
    VeilStepperNavComponent.prototype.isButtonNavDisabled = function (index) {
        if (this.erroredArray[this.activeIndex] === true && index > this.activeIndex) {
            return true;
        }
        if (index === this.activeIndex || this.successArray[index]) {
            return false;
        }
        return true;
    };
    VeilStepperNavComponent.prototype.navigateToStep = function (index) {
        this.stepperService.navigateToStep(index);
    };
    VeilStepperNavComponent.prototype.listenForActiveStep = function () {
        var _this = this;
        return this.stepperService.getActiveStep().subscribe(function (index) {
            _this.activeIndex = index;
        });
    };
    VeilStepperNavComponent.prototype.listenForActiveStepError = function () {
        var _this = this;
        return this.stepperService.getActiveStepError().subscribe(function (error) {
            _this.successArray[_this.activeIndex] = !error;
            _this.erroredArray[_this.activeIndex] = error;
        });
    };
    VeilStepperNavComponent.ctorParameters = function () { return [
        { type: StepperService }
    ]; };
    __decorate([
        Input()
    ], VeilStepperNavComponent.prototype, "navTitles", void 0);
    VeilStepperNavComponent = __decorate([
        Component({
            selector: 'veil-stepper-nav',
            template: "<ul>\n  <li *ngFor=\"let title of navTitles; index as i;\">\n    <button\n      [ngClass]=\"{ active: i === activeIndex, error: isErrored(i), success: isSuccess(i) }\"\n      (click)=\"navigateToStep(i)\"\n      [disabled]=\"isButtonNavDisabled(i)\"\n      type=\"button\"\n    >\n      <span class=\"error\" *ngIf=\"isErrored(i)\">\n        <i class=\"fa fa-exclamation-circle\" aria-hidden=\"true\"></i> \n      </span>\n      <span class=\"success\" *ngIf=\"isSuccess(i)\">\n        <i class=\"fa fa-check-circle-o\" aria-hidden=\"true\"></i>\n      </span>\n      <span class=\"count\" *ngIf=\"!(isErrored(i) || isSuccess(i))\">{{ i + 1 }}. </span>\n      <span class=\"title\">{{ title }}</span>\n    </button>\n  </li>\n</ul>\n",
            styles: [":host{width:200px;border-right:1px solid #ccc}:host ul{padding:0;margin:0;list-style:none}:host button{width:100%;padding:.6rem;border:none;text-align:left;border-bottom:1px solid #ccc;background-color:#fafafa;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;cursor:pointer;outline:0}:host button:disabled{color:inherit;cursor:default}:host button.active{-webkit-box-shadow:2px 0 0 0 #0072a3 inset;box-shadow:2px 0 0 0 #0072a3 inset;font-weight:700}:host button.error{-webkit-box-shadow:2px 0 0 0 #db2100 inset;box-shadow:2px 0 0 0 #db2100 inset}:host button.success{-webkit-box-shadow:2px 0 0 0 #3c8500 inset;box-shadow:2px 0 0 0 #3c8500 inset}:host button .error{color:#db2100;padding-right:4px}:host button .success{color:#3c8500;padding-right:4px}"]
        })
    ], VeilStepperNavComponent);
    return VeilStepperNavComponent;
}());

var StepButtonType;
(function (StepButtonType) {
    StepButtonType["Next"] = "next";
    StepButtonType["Submit"] = "submit";
})(StepButtonType || (StepButtonType = {}));
var StepButtonDirective = /** @class */ (function () {
    function StepButtonDirective(stepper, vlStep, stepperService) {
        this.stepper = stepper;
        this.vlStep = vlStep;
        this.stepperService = stepperService;
        /* tslint:disable-next-line:no-input-rename */
        this.type = StepButtonType.Next;
        this.submitButton = false;
    }
    StepButtonDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.listenForValueChanges = this.stepper.form.valueChanges.subscribe(function (_) {
            if (_this.stepper.form.valid && _this.type === StepButtonType.Submit) {
                _this.submitButton = true;
            }
            else {
                _this.submitButton = false;
            }
        });
    };
    StepButtonDirective.prototype.ngOnDestroy = function () {
        this.listenForValueChanges.unsubscribe();
    };
    StepButtonDirective.prototype.navigateToNextPanel = function () {
        this.stepperService.navigateToNextStep(this.vlStep.id, this.vlStep.formGroup.valid);
    };
    StepButtonDirective.ctorParameters = function () { return [
        { type: VeilStepperComponent },
        { type: VeilStepperStepComponent },
        { type: StepperService }
    ]; };
    __decorate([
        Input('veilStepButton')
    ], StepButtonDirective.prototype, "type", void 0);
    __decorate([
        HostListener('click')
    ], StepButtonDirective.prototype, "navigateToNextPanel", null);
    StepButtonDirective = __decorate([
        Directive({
            selector: '[veilStepButton]',
            /* tslint:disable-next-line */
            host: {
                '[type]': 'this.submitButton ? \'submit\' : \'button\'',
            },
        })
    ], StepButtonDirective);
    return StepButtonDirective;
}());

var VeilStepperModule = /** @class */ (function () {
    function VeilStepperModule() {
    }
    VeilStepperModule = __decorate([
        NgModule({
            exports: [
                VeilStepperComponent,
                VeilStepperStepComponent,
                VeilStepperNavComponent,
                StepButtonDirective
            ],
            imports: [
                CommonModule,
                VeilButtonModule
            ],
            declarations: [
                VeilStepperComponent,
                VeilStepperStepComponent,
                VeilStepperNavComponent,
                StepButtonDirective
            ],
            providers: [
                StepperService
            ]
        })
    ], VeilStepperModule);
    return VeilStepperModule;
}());

var VeilUIKitModule = /** @class */ (function () {
    function VeilUIKitModule() {
    }
    VeilUIKitModule = __decorate([
        NgModule({
            exports: [
                VeilButtonModule,
                VeilCheckboxModule,
                VeilInputModule,
                VeilLayoutModule,
                VeilTableModule,
                VeilSelectModule,
                VeilSidenavModule,
                VeilSpinnerModule,
                VeilListModule,
                VeilDropdownModule,
                VeilTreeModule,
                VeilDatepickerModule,
                VeilMultiselectModule,
                VeilPaginatorModule,
                VeilTimepickerModule,
                VeilDatetimepickerModule,
                VeilBadgeModule,
                VeilProgressBarModule,
                VeilStepperModule
            ]
        })
    ], VeilUIKitModule);
    return VeilUIKitModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { StepButtonDirective, StepButtonType, VeilBadgeComponent, VeilBadgeModule, VeilButtonComponent, VeilButtonModule, VeilCheckboxComponent, VeilCheckboxModule, VeilDatepickerComponent, VeilDatepickerModule, VeilDatetimepickerComponent, VeilDatetimepickerModule, VeilDropdownComponent, VeilDropdownControlComponent, VeilDropdownMenuComponent, VeilDropdownModule, VeilInputComponent, VeilInputModule, VeilLayoutComponent, VeilLayoutContentComponent, VeilLayoutControlsComponent, VeilLayoutFooterComponent, VeilLayoutModule, VeilLayoutTitleComponent, VeilLineComponent, VeilLineItemComponent, VeilLineTitleComponent, VeilListComponent, VeilListModule, VeilListTitleComponent, VeilMultiselectComponent, VeilMultiselectModule, VeilPaginatorComponent, VeilPaginatorModule, VeilProgressBarComponent, VeilProgressBarModule, VeilSelectComponent, VeilSelectModule, VeilSidenavComponent, VeilSidenavModule, VeilSpinnerComponent, VeilSpinnerModule, VeilStepperComponent, VeilStepperModule, VeilStepperNavComponent, VeilStepperStepComponent, VeilTableComponent, VeilTableModule, VeilTbodyComponent, VeilTdComponent, VeilThComponent, VeilTheadComponent, VeilTimepickerComponent, VeilTimepickerModule, VeilToggleDirective, VeilTrComponent, VeilTreeComponent, VeilTreeModule, VeilUIKitModule, uniqueId as ɵa, uniqueIdFactory as ɵb, UNIQUE_ID_PROVIDER as ɵc, StepperService as ɵd };
//# sourceMappingURL=veil-ui-kit.js.map
