"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var schematics_1 = require("@angular/cdk/schematics");
var fs = require("fs");
var util_1 = require("../util");
function default_1(options) {
    return function (tree, context) {
        var configFile = 'angular.json';
        if (!fs.existsSync(configFile)) {
            console.error('Could not install VeiL UI Kit, requires Angular and Angular CLI version 6 or greater');
            return;
        }
        var config = util_1.readJSON(tree, configFile);
        if (!options.project) {
            if (!config.defaultProject) {
                console.error('Could not find a default project, please specify --project PROJECT_NAME');
                return;
            }
            options.project = config.defaultProject;
        }
        // Add VeiL UI Kit and Font Awesome assets to angular.json, if not found
        (function () {
            var projects = Object.keys(config.projects);
            var project = projects.find(function (key) {
                if (key === options.project) {
                    return true;
                }
                return false;
            });
            if (!project) {
                console.error("Could not update CLI config file to add scripts and styles. You'll have to add them manually.");
                return;
            }
            var target = config.projects[project].targets ? config.projects[project].targets : config.projects[project].architect;
            var styles = target.build.options.styles;
            var stylesSearch = styles.join('|');
            var pathPrefix = config.apps ? '../' : '';
            if (stylesSearch.search('node_modules/veil-ui-kit/src/styles/main') < 0) {
                styles.unshift(pathPrefix + "node_modules/veil-ui-kit/src/styles/main.css");
            }
            if (stylesSearch.search('node_modules/font-awesome/css/font-awesome.min.css') < 0) {
                styles.unshift(pathPrefix + "node_modules/font-awesome/css/font-awesome.min.css");
            }
            util_1.writeJSON(tree, configFile, config);
        })();
        // Add a VeilUIKitModule to the AppModule
        var project = util_1.getProject(tree, options.project);
        schematics_1.addModuleImportToRootModule(tree, 'VeilUIKitModule', 'veil-ui-kit', project);
    };
}
exports.default = default_1;
